/* This file is part of the Amalthea library.
 *
 * Copyright (C) 2019-2022 Eugene 'Vindex' Stulin
 *
 * The Amalthea library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This libary is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

module amalthea.fileformats;

import
    std.algorithm,
    std.array,
    std.datetime,
    std.file,
    std.format,
    std.json,
    std.path,
    std.process,
    std.stdio,
    std.string,
    std.typecons,
    std.utf;

import amalthea.dataprocessing : calcIntersection;

pragma(lib, "gio-2.0");
pragma(lib, "glib-2.0");


struct Signature {
    /// Key byte sequence.
    ubyte[] bytes;
    /// Offset of the signature from the beginning of the file.
    uint offset;
}


/*******************************************************************************
 * File format info.
 */
struct FileFormat {
    /// Format name.
    string format;
    /// Key byte sequences and offsets.
    Signature[] signatures;
    /// List of file suffixes used by the format.
    string[] extensions;
    /// Format brief description.
    string description;
    /// Big description. Reserved for future use.
    string extendedDescription;
    /// Format group name (Audio, Pictures, Archives, etc.).
    string group;
    
    /// Implements comparison.
    int opCmp(FileFormat rhs) {
        if (this.format > rhs.format) {
            return 1;
        }
        if (this.format < rhs.format) {
            return -1;
        }
        return 0;
    }
}


/*******************************************************************************
 * The function gets the FileFormat structure with info about file format.
 *
 * Paramams:
 *     filepath = Path to required file.
 *     additExt = File extension as hint for recognition algorithm.
 *                Not needed in most cases. Can be used if for some reason
 *                the file name does not have an extension.
 *
 * Returns: a FileFormat object containing some format information.
 */
FileFormat getFileFormat(string filepath, string additExt) {
    if (!filepath.exists || !filepath.isFile) {
        throw new FileException("File is not regular or not readable.");
    }
    return signatureSearch(filepath, additExt);
}
/// ditto
FileFormat getFileFormat(string filepath) {
    return getFileFormat(filepath, "");
}


/*******************************************************************************
 * The function returns true if specified file contains plain Unicode-text.
 */
bool isUnicodeTextFile(string filepath) nothrow {
    try {
        File(filepath, "r").byLine.each!validate;
    } catch (Exception e) {
        return false;
    }
    return true;
}


private FileFormat[] searchByExtHint(in FileFormat[] candidates,
                                     string additExt) {
    additExt = additExt.toLower;
    FileFormat[] newCandidatesWithExtensions;
    FileFormat[] newCandidatesWithoutExtensions;
    foreach(ftype; candidates) {
        foreach(ext; ftype.extensions) {
            if (ext == "*") {
                newCandidatesWithoutExtensions ~= cast(FileFormat)ftype;
            } else if (additExt == ext) {
                newCandidatesWithExtensions ~= cast(FileFormat)ftype;
            }
        }
    }
    return newCandidatesWithoutExtensions ~ newCandidatesWithExtensions;
}


private FileFormat[] searchByExtensions(in FileFormat[] candidates,
                                        string fpath) {
    fpath = fpath.toLower;
    FileFormat[] newCandidatesWithExtensions;
    FileFormat[] newCandidatesWithoutExtensions;
    foreach(ftype; candidates) {
        foreach(ext; ftype.extensions) {
            auto end = "." ~ ext;
            if (ext == "*") {
                newCandidatesWithoutExtensions ~= cast(FileFormat)ftype;
            } else if (fpath.endsWith(end) || fpath.canFind(end ~ ".")) {
                newCandidatesWithExtensions ~= cast(FileFormat)ftype;
            }
        }
    }
    return newCandidatesWithoutExtensions ~ newCandidatesWithExtensions;
}


static FileFormat[] searchBySignature(in FileFormat[] candidates,
                                      in ubyte[] data) {
    FileFormat[] newCandidates;
    foreach(ftype; candidates) {
        foreach(s; ftype.signatures) {
            auto off = s.offset;
            auto signature = s.bytes;
            if (signature.length + off > data.length) {
                continue;
            }
            if (signature.empty) {
                newCandidates ~= cast(FileFormat)ftype;
                break;
            } else if (signature == data[off .. off + signature.length]) {
                newCandidates ~= cast(FileFormat)ftype;
                break;
            }
        }
    }
    return newCandidates;
}


private FileFormat identifyLikelySignature(FileFormat[] candidates,
                                           ubyte[] data)
in {
    assert(candidates.length > 1);
}
do {
    size_t getMaxNumberOfBytes(Signature[] signatures) {
        size_t maxNumber;
        foreach(s; signatures) {
            if (signatures.length > maxNumber) {
                maxNumber = signatures.length;
            }
        }
        return maxNumber;
    }
    FileFormat result = candidates[0];
    size_t maxNumberOfBytes = getMaxNumberOfBytes(result.signatures);
    size_t currentFormatMaxSignatureLength;
    foreach(f; candidates[1 .. $]) {
        currentFormatMaxSignatureLength = getMaxNumberOfBytes(f.signatures);
        if (currentFormatMaxSignatureLength > maxNumberOfBytes) {
            maxNumberOfBytes = currentFormatMaxSignatureLength;
            result = f;
        }
    }
    return result;
}


private bool identifyFacelessFile(string filepath) {
    if (std.path.extension(filepath) == "" && std.file.getSize(filepath) == 0) {
        return true;
    }
    return false;
}


private FileFormat getPlainTextFormat() {
    return FileFormat("TXT", null, null, "Plain text document", "", "Text");
}


private FileFormat signatureSearch(string filepath, string additExt = "") {
    auto f = File(filepath, "r");
    ubyte[] buffer;
    buffer.length = 1024;
    ubyte[] data = f.rawRead(buffer);

    FileFormat[] signCandidates = searchBySignature(fileformats, data);
    if (signCandidates.empty) {
        if (identifyFacelessFile(filepath)) {
            return getPlainTextFormat();
        }
        return altFormatSearch(filepath);
    }
    if (signCandidates.length == 1 && !signCandidates[0].signatures.empty) {
        return signCandidates[0];
    }
    FileFormat[] extCandidates = additExt.empty ?
        searchByExtensions(fileformats, filepath) :
        searchByExtHint(fileformats, additExt);
    FileFormat[] candidates = calcIntersection(signCandidates, extCandidates);
    if (candidates.empty) {
        signCandidates = signCandidates.filter!(c => !c.signatures.empty).array;
        if (signCandidates.empty) {
            return altFormatSearch(filepath);
        }
        return identifyLikelySignature(signCandidates, data);
    }
    if (candidates.length == 1) {
        return candidates[0];
    }
    // candidates.length > 1
    return identifyLikelySignature(candidates, data);
}


extern(C)
static char* g_content_type_guess(const char* filename,
                                  const byte* data,
                                  size_t data_size,
                                  bool* result_uncertain);

extern(C)
static void g_free(void* mem);

extern(C)
char* g_content_type_get_mime_type(const char* type);

extern(C)
char* g_content_type_get_description(const char* type);


/// Returns tuple with MIME type and its description.
auto contentTypeGuess(alias useEnglish=true)(string filepath) {
    static if (useEnglish) {
        auto lang = environment.get("LANG", "");
        environment["LANG"] = "C";
        scope(exit) environment["LANG"] = lang;
    }

    auto raw = cast(byte[])read(filepath, 1024);
    byte* data = raw.ptr;
    char* type = g_content_type_guess(
        filepath.toStringz, data, raw.length, null
    );
    string mimetype = type.fromStringz.idup;
    char* descr = g_content_type_get_description(type);
    string description = descr.fromStringz.idup;
    g_free(type);
    g_free(descr);
    return tuple(mimetype, description);
}


private FileFormat altFormatSearch(string filepath) {
    string ext = std.path.extension(filepath).stripLeft('.');
    auto mimeAndDescription = contentTypeGuess(filepath);
    string mimetype = mimeAndDescription[0];
    string mimegroup = mimetype.split('/')[0];
    string mimeformat = mimetype.split('/')[1];
    string description = mimeAndDescription[1];

    FileFormat ff;
    ff.format = ext.empty ? mimeformat : ext.toUpper;
    ff.description = description.capitalize;
    if (ff.description == "Plain text document" && ff.format == "plain") {
        ff.format = "TXT";
    } else if (mimeformat.endsWith("src")) {
        ff.format = ff.description;
    }
    if (isUnicodeTextFile(filepath) || mimegroup == "text") {
        ff.group = "Text";
    }
    return ff;
}


immutable string canonBase = "/etc/amalthea/fileformats.json";
immutable string configHomeDir;
immutable string homeBase;
shared static this() {
    configHomeDir = buildPath(environment["HOME"], ".config", "amalthea");
    homeBase = buildPath(configHomeDir, "fileformats.json");
    if (!exists(canonBase)) {
        std.file.mkdirRecurse(configHomeDir);
        std.file.write(homeBase, fileformatsJSONText);
    }
    loadFileFormatBase();
}


private __gshared FileFormat[] fileformats;

/// Returns array of supported file formats.
FileFormat[] getAllFileFormats() {
    return fileformats.dup;
}


private void loadFileFormatBase() {
    string text;
    if (!exists(canonBase)) {
        text = readText(homeBase);
    } else {
        text = readText(canonBase);
    }
    auto jsonFormatArray = parseJSON(text).array;
    auto spec = singleSpec("%x");
    foreach(j; jsonFormatArray) {
        FileFormat newFormat;
        newFormat.format = j["format"].str;
        foreach(s; j["signatures"].array) {
            Signature newSignature;
            newSignature.offset = cast(uint)s["offset"].integer;
            foreach(strByte; s["hex_signature"].str.split(' ')) {
                newSignature.bytes ~= unformatValue!ubyte(strByte, spec);
            }
            newFormat.signatures ~= newSignature;
        }
        foreach(ext; j["extensions"].array) {
            newFormat.extensions ~= ext.str;
        }
        newFormat.description = j["description"].str;
        if ("extended_description" in j) {
            newFormat.extendedDescription = j["extended_description"].str;
        }
        newFormat.group = j["group"].str;
        fileformats ~= newFormat;
    }
}

//json text is inserted from json file (`make update_fileformats`)
//This text is not for editing from here.
private immutable fileformatsJSONText = 
`
[
{
    "format": "PIC",
    "signatures": [
        {
            "hex_signature": "00",
            "offset": 0
        }
    ],
    "extensions": ["pic"],
    "description": "IBM Storyboard bitmap file",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "PIF",
    "signatures": [
        {
            "hex_signature": "00",
            "offset": 0
        }
    ],
    "extensions": ["pif"],
    "description": "Windows Program Information File",
    "extended_description": "",
    "group": ""
},
{
    "format": "SEA",
    "signatures": [
        {
            "hex_signature": "00",
            "offset": 0
        }
    ],
    "extensions": ["sea"],
    "description": "Mac Stuffit Self-Extracting Archive",
    "extended_description": "",
    "group": ""
},
{
    "format": "YTR",
    "signatures": [
        {
            "hex_signature": "00",
            "offset": 0
        }
    ],
    "extensions": ["ytr"],
    "description": "IRIS OCR data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "PDB",
    "signatures": [
        {
            "hex_signature": "00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00",
            "offset": 11
        },
        {
            "hex_signature": "73 6D 5F",
            "offset": 0,
            "comment": "Special signature for PalmOS Supermemo files"
        }
    ],
    "extensions": ["pdb"],
    "description": "PalmOS Database/Document File",
    "extended_description": "",
    "group": ""
},
{
    "format": "JPEG-2000",
    "signatures": [
        {
            "hex_signature": "00 00 00 0C 6A 50 20 20",
            "offset": 0
        }
    ],
    "extensions": ["jp2"],
    "description": "JPEG-2000 image",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "ICO",
    "signatures": [
        {
            "hex_signature": "00 00 01 00",
            "offset": 0
        }
    ],
    "extensions": ["ico"],
    "description": "Windows icon file",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "SPL",
    "signatures": [
        {
            "hex_signature": "00 00 01 00",
            "offset": 0
        }
    ],
    "extensions": ["spl"],
    "description": "Windows printer spool file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MPEG",
    "signatures": [
        {
            "hex_signature": "00 00 01",
            "offset": 0
        }
    ],
    "extensions": ["mpg", "m2p", "mpeg"],
    "description": "MPEG video file",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "VOB",
    "signatures": [
        {
            "hex_signature": "00 00 01",
            "offset": 0
        }
    ],
    "extensions": ["vob"],
    "description": "DVD video file",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "WB2",
    "signatures": [
        {
            "hex_signature": "00 00 02 00",
            "offset": 0
        }
    ],
    "extensions": ["wb2"],
    "description": "QuattroPro spreadsheet",
    "extended_description": "",
    "group": ""
},
{
    "format": "CUR",
    "signatures": [
        {
            "hex_signature": "00 00 02 00",
            "offset": 0
        }
    ],
    "extensions": ["cur"],
    "description": "Windows cursor",
    "extended_description": "",
    "group": ""
},
{
    "format": "WK1",
    "signatures": [
        {
            "hex_signature": "00 00 02 00 06 04 06 00 08",
            "offset": 0
        }
    ],
    "extensions": ["wk1"],
    "description": "Lotus 1-2-3 (v.1)",
    "extended_description": "",
    "group": ""
},
{
    "format": "WK3",
    "signatures": [
        {
            "hex_signature": "00 00 1A 00 00 10 04",
            "offset": 0
        }
    ],
    "extensions": ["wk3"],
    "description": "Lotus 1-2-3 (v.3)",
    "extended_description": "",
    "group": ""
},
{
    "format": "WK4",
    "signatures": [
        {
            "hex_signature": "00 00 1A 00 02 10 04",
            "offset": 0
        }
    ],
    "extensions": ["wk4"],
    "description": "Lotus 1-2-3 (v.4)",
    "extended_description": "",
    "group": ""
},
{
    "format": "WK5",
    "signatures": [
        {
            "hex_signature": "00 00 1A 00 02 10 04",
            "offset": 0
        }
    ],
    "extensions": ["wk5"],
    "description": "Lotus 1-2-3 (v.5)",
    "extended_description": "",
    "group": ""
},
{
    "format": "123",
    "signatures": [
        {
            "hex_signature": "00 00 1A 00 05 10 04",
            "offset": 0
        }
    ],
    "extensions": ["123"],
    "description": "Lotus 1-2-3 (v.9)",
    "extended_description": "",
    "group": ""
},
{
    "format": "QXD",
    "signatures": [
        {
            "hex_signature": "00 00 49 49 58 50 52",
            "offset": 0,
            "comment": "QuarkXPress (Intel)"
        },
        {
            "hex_signature": "00 00 4D 4D 58 50 52",
            "offset": 0,
            "comment": "QuarkXPress (Motorola)"
        }
    ],
    "extensions": ["qxd"],
    "description": "QuarkXPress document",
    "extended_description": "",
    "group": ""
},
{
    "format": "HLP",
    "signatures": [
        {
            "hex_signature": "00 00 FF FF FF FF",
            "offset": 6
        },
        {
            "hex_signature": "3F 5F 03 00",
            "offset": 0
        },
        {
            "hex_signature": "4C 4E 02 00",
            "offset": 0
        }
    ],
    "extensions": ["hlp", "gid"],
    "description": "Windows Help",
    "extended_description": "",
    "group": ""
},
{
    "format": "MNY",
    "signatures": [
        {
            "hex_signature": "00 01 00 00 4D 53 49 53 41 4D 20 44 61 74 61 62 61 73 65",
            "offset": 0
        }
    ],
    "extensions": ["mny"],
    "description": "Microsoft Money file",
    "extended_description": "",
    "group": ""
},
{
    "format": "ACCDB",
    "signatures": [
        {
            "hex_signature": "00 01 00 00 53 74 61 6E 64 61 72 64 20 41 43 45 20 44 42",
            "offset": 0
        }
    ],
    "extensions": ["accdb"],
    "description": "Microsoft Access 2007 file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MDB",
    "signatures": [
        {
            "hex_signature": "00 01 00 00 53 74 61 6E 64 61 72 64 20 4A 65 74 20 44 42",
            "offset": 0
        }
    ],
    "extensions": ["mdb"],
    "description": "Microsoft Access file",
    "extended_description": "",
    "group": ""
},
{
    "format": "ABA",
    "signatures": [
        {
            "hex_signature": "00 01 42 41",
            "offset": 0
        }
    ],
    "extensions": ["aba"],
    "description": "Palm Address Book Archive",
    "extended_description": "",
    "group": ""
},
{
    "format": "DBA",
    "signatures": [
        {
            "hex_signature": "00 01 42 44",
            "offset": 0
        }
    ],
    "extensions": ["dba"],
    "description": "Palm DateBook Archive",
    "extended_description": "",
    "group": ""
},
{
    "format": "Netscape Database",
    "signatures": [
        {
            "hex_signature": "00 06 15 61 00 00 00 02 00 00 04 D2 00 00 10 00",
            "offset": 0
        }
    ],
    "extensions": ["db"],
    "description": "Netscape Navigator (v.4) database",
    "extended_description": "",
    "group": ""
},
{
    "format": "FLIC",
    "signatures": [
        {
            "hex_signature": "00 11 AF",
            "offset": 0
        }
    ],
    "extensions": ["fli"],
    "description": "FLIC animation",
    "extended_description": "",
    "group": ""
},
{
    "format": "BIOS details in RAM",
    "signatures": [
        {
            "hex_signature": "00 14 00 00 01 02",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "BIOS details in RAM",
    "extended_description": "",
    "group": ""
},
{
    "format": "SNM",
    "signatures": [
        {
            "hex_signature": "00 1E 84 90 00 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["snm"],
    "description": "Netscape Communicator (v.4) mail folder",
    "extended_description": "",
    "group": ""
},
{
    "format": "WASM",
    "signatures": [
        {
            "hex_signature": "00 61 73 6d",
            "offset": 0
        }
    ],
    "extensions": ["wasm"],
    "description": "WebAssembly binary format",
    "extended_description": "",
    "group": ""
},
{
    "format": "MS SQL Server Database",
    "signatures": [
        {
            "hex_signature": "01 0F 00 00",
            "offset": 0
        }
    ],
    "extensions": ["mdf"],
    "description": "MS SQL Server Database",
    "extended_description": "",
    "group": ""
},
{
    "format": "TR1",
    "signatures": [
        {
            "hex_signature": "01 10",
            "offset": 0
        }
    ],
    "extensions": ["tr1"],
    "description": "Novell LANalyzer capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "RGB",
    "signatures": [
        {
            "hex_signature": "01 DA 01 01 00 03",
            "offset": 0
        }
    ],
    "extensions": ["rgb"],
    "description": "Silicon Graphics RGB Bitmap",
    "extended_description": "",
    "group": ""
},
{
    "format": "DRW",
    "signatures": [
        {
            "hex_signature": "01 FF 02 04 03 02",
            "offset": 0
        }
    ],
    "extensions": ["drw"],
    "description": "Micrografx vector graphic file",
    "extended_description": "",
    "group": ""
},
{
    "format": "DSS",
    "signatures": [
        {
            "hex_signature": "02 64 73 73",
            "offset": 0
        }
    ],
    "extensions": ["dss"],
    "description": "Digital Speech Standard file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MapInfo Native Data Format",
    "signatures": [
        {
            "hex_signature": "03",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "MapInfo Native Data Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "DB3",
    "signatures": [
        {
            "hex_signature": "03",
            "offset": 0
        }
    ],
    "extensions": ["db3"],
    "description": "dBASE III file",
    "extended_description": "",
    "group": ""
},
{
    "format": "QPH",
    "signatures": [
        {
            "hex_signature": "03 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["qph"],
    "description": "Quicken price history",
    "extended_description": "",
    "group": ""
},
{
    "format": "Approach Index File",
    "signatures": [
        {
            "hex_signature": "03 00 00 00 41 50 50 52",
            "offset": 0
        }
    ],
    "extensions": ["adx"],
    "description": "Lotus Approach index file",
    "extended_description": "",
    "group": ""
},
{
    "format": "DB4",
    "signatures": [
        {
            "hex_signature": "04",
            "offset": 0
        }
    ],
    "extensions": ["db4"],
    "description": "dBASE IV file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Windows recycle bin",
    "signatures": [
        {
            "hex_signature": "04 00 00 00",
            "offset": 0
        },
        {
            "hex_signature": "05 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "INFO2 Windows recycle",
    "extended_description": "",
    "group": ""
},
{
    "format": "LZ4",
    "signatures": [
        {
            "hex_signature": "04 22 4D 18",
            "offset": 0
        }
    ],
    "extensions": ["lz4"],
    "description": "LZ4 Frame Format",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "CWK",
    "signatures": [
        {
            "hex_signature": "05 07 00 00 42 4F 42 4F",
            "offset": 0
        },
        {
            "hex_signature": "06 07 E1 00 42 4F 42 4F",
            "offset": 0
        }
    ],
    "extensions": ["cwk"],
    "description": "AppleWorks document",
    "extended_description": "",
    "group": ""
},
{
    "format": "Generic Draw File",
    "signatures": [
        {
            "hex_signature": "07",
            "offset": 0
        }
    ],
    "extensions": ["drw"],
    "description": "Generic draw file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SKF",
    "signatures": [
        {
            "hex_signature": "07 53 4B 46",
            "offset": 0
        }
    ],
    "extensions": ["skf"],
    "description": "SkinCrafter skin",
    "extended_description": "",
    "group": ""
},
{
    "format": "DTD",
    "signatures": [
        {
            "hex_signature": "07 64 74 32 64 64 74 64",
            "offset": 0
        }
    ],
    "extensions": ["dtd"],
    "description": "DesignTools 2D Design file",
    "extended_description": "",
    "group": ""
},
{
    "format": "DBASE",
    "signatures": [
        {
            "hex_signature": "08",
            "offset": 0
        }
    ],
    "extensions": ["db"],
    "description": "dBASE IV or dBFast configuration file",
    "extended_description": "",
    "group": ""
},
{
    "format": "PCX",
    "signatures": [
        {
            "hex_signature": "0A 02 01",
            "offset": 0
        },
        {
            "hex_signature": "0A 03 01",
            "offset": 0
        },
        {
            "hex_signature": "0A 04 01",
            "offset": 0
        },
        {
            "hex_signature": "0A 05 01",
            "offset": 0
        }
    ],
    "extensions": ["pcx"],
    "description": "ZSOFT Paintbrush",
    "extended_description": "",
    "group": ""
},
{
    "format": "PCANPG",
    "signatures": [
        {
            "hex_signature": "0A 0D 0D 0A",
            "offset": 0
        }
    ],
    "extensions": ["pcapng"],
    "description": "PCAP Next Generation Dump File Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "MP",
    "signatures": [
        {
            "hex_signature": "0C ED",
            "offset": 0
        }
    ],
    "extensions": ["mp"],
    "description": "Monochrome Picture TIFF bitmap",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "DeskMate Document",
    "signatures": [
        {
            "hex_signature": "0D 44 4F 43",
            "offset": 0
        }
    ],
    "extensions": ["doc"],
    "description": "DeskMate document",
    "extended_description": "",
    "group": ""
},
{
    "format": "NRI",
    "signatures": [
        {
            "hex_signature": "0E 4E 65 72 6F 49 53 4F",
            "offset": 0
        }
    ],
    "extensions": ["nri"],
    "description": "Nero CD compilation",
    "extended_description": "",
    "group": ""
},
{
    "format": "DeskMate Worksheet",
    "signatures": [
        {
            "hex_signature": "0E 57 4B 53",
            "offset": 0
        }
    ],
    "extensions": ["wks"],
    "description": "DeskMate Worksheet",
    "extended_description": "",
    "group": ""
},
{
    "format": "PF",
    "signatures": [
        {
            "hex_signature": "53 43 43 41",
            "offset": 4
        }
    ],
    "extensions": ["pf"],
    "description": "Windows prefetch file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Lotus Notes Database Template",
    "signatures": [
        {
            "hex_signature": "1A 00 00",
            "offset": 0
        }
    ],
    "extensions": ["ntf"],
    "description": "Lotus Notes database template",
    "extended_description": "",
    "group": ""
},
{
    "format": "Lotus Notes Database",
    "signatures": [
        {
            "hex_signature": "1A 00 00 04 00 00",
            "offset": 0
        }
    ],
    "extensions": ["nsf"],
    "description": "Lotus Notes database",
    "extended_description": "",
    "group": ""
},
{
    "format": "ARC",
    "signatures": [
        {
            "hex_signature": "1A 02",
            "offset": 0
        },
        {
            "hex_signature": "1A 03",
            "offset": 0
        },
        {
            "hex_signature": "1A 04",
            "offset": 0
        },
        {
            "hex_signature": "1A 08",
            "offset": 0
        },
        {
            "hex_signature": "1A 09",
            "offset": 0
        }
    ],
    "extensions": ["arc"],
    "description": "LH archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "PAK",
    "signatures": [
        {
            "hex_signature": "1A 0B",
            "offset": 0
        }
    ],
    "extensions": ["pak"],
    "description": "PAK Compressed archive file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "ETH",
    "signatures": [
        {
            "hex_signature": "1A 35 01 00",
            "offset": 0
        }
    ],
    "extensions": ["eth"],
    "description": "WinPharoah capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MKV",
    "signatures": [
        {
            "hex_signature": "1A 45 DF A3",
            "offset": 0
        }
    ],
    "extensions": ["mkv"],
    "description": "Matroska media container",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "WEBM",
    "signatures": [
        {
            "hex_signature": "1A 45 DF A3",
            "offset": 0
        }
    ],
    "extensions": ["webm"],
    "description": "WebM video file",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "Runtime Software Disk Image",
    "signatures": [
        {
            "hex_signature": "1A 52 54 53 20 43 4F 4D",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Runtime Software disk image",
    "extended_description": "",
    "group": ""
},
{
    "format": "Lua Bytecode",
    "signatures": [
        {
            "hex_signature": "1B 4C 75 61",
            "offset": 0
        }
    ],
    "extensions": ["luac"],
    "description": "Lua bytecode",
    "extended_description": "",
    "group": ""
},
{
    "format": "WS",
    "signatures": [
        {
            "hex_signature": "1D 7D",
            "offset": 0
        }
    ],
    "extensions": ["ws"],
    "description": "WordStar document",
    "extended_description": "",
    "group": ""
},
{
    "format": "GZIP",
    "signatures": [
        {
            "hex_signature": "1F 8B 08",
            "offset": 0
        }
    ],
    "extensions": ["gz", "tgz"],
    "description": "GZIP archive file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "LZV",
    "signatures": [
        {
            "hex_signature": "1F 9D",
            "offset": 0
        }
    ],
    "extensions": ["tar.z", "z"],
    "description": "LZV archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "LZH",
    "signatures": [
        {
            "hex_signature": "1F A0",
            "offset": 0
        }
    ],
    "extensions": ["tar.z", "z"],
    "description": "LZH archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "TDE",
    "signatures": [
        {
            "hex_signature": "20 02 01 62 A0 1E AB 07 02 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["tde"],
    "description": "Tableau Datasource",
    "extended_description": "",
    "group": ""
},
{
    "format": "AIN",
    "signatures": [
        {
            "hex_signature": "21 12",
            "offset": 0
        }
    ],
    "extensions": ["ain"],
    "description": "AIN Compressed Archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "DEB",
    "signatures": [
        {
            "hex_signature": "21 3C 61 72 63 68 3E",
            "offset": 0
        }
    ],
    "extensions": ["deb"],
    "description": "Debian package format",
    "extended_description": "",
    "group": ""
},
{
    "format": "LIB",
    "signatures": [
        {
            "hex_signature": "21 3C 61 72 63 68 3E 0A",
            "offset": 0
        }
    ],
    "extensions": ["lib"],
    "description": "MS Program Library Common Object File Format",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "Cerius2 File",
    "signatures": [
        {
            "hex_signature": "23 20",
            "offset": 0
        }
    ],
    "extensions": ["msi"],
    "description": "Cerius2 file",
    "extended_description": "",
    "group": ""
},
{
    "format": "VMDK",
    "signatures": [
        {
            "hex_signature": "23 20 44 69 73 6B 20 44",
            "offset": 0
        },
                {
            "hex_signature": "43 4F 57 44",
            "offset": 0
        },
        {
            "hex_signature": "4B 44 4D",
            "offset": 0
        }
    ],
    "extensions": ["vmdk"],
    "description": "VMware Virtual Disk",
    "extended_description": "",
    "group": ""
},
{
    "format": "DSP",
    "signatures": [
        {
            "hex_signature": "23 20 4D 69 63 72 6F 73",
            "offset": 0
        }
    ],
    "extensions": ["dsp"],
    "description": "MS Developer Studio project file",
    "extended_description": "",
    "group": ""
},
{
    "format": "AMR",
    "signatures": [
        {
            "hex_signature": "23 21 41 4D 52",
            "offset": 0
        }
    ],
    "extensions": ["amr"],
    "description": "Adaptive Multi-Rate ACELP Codec",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "HDR",
    "signatures": [
        {
            "hex_signature": "23 3F 52 41 44 49 41 4E",
            "offset": 0
        }
    ],
    "extensions": ["hdr"],
    "description": "Radiance High Dynamic Range image file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SPSS Data file",
    "signatures": [
        {
            "hex_signature": "24 46 4C 32 40 28 23 29",
            "offset": 0
        }
    ],
    "extensions": ["sav"],
    "description": "SPSS Data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "System Deployment Image",
    "signatures": [
        {
            "hex_signature": "24 53 44 49 30 30 30 31",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Disk image format used by Microsoft",
    "extended_description": "",
    "group": ""
},
{
    "format": "PS",
    "signatures": [
        {
            "hex_signature": "25 21 50 53",
            "offset": 0
        }
    ],
    "extensions": ["ps"],
    "description": "PostScript document",
    "extended_description": "",
    "group": ""
},
{
    "format": "EPS",
    "signatures": [
        {
            "hex_signature": "25 21 50 53 2D 41 64 6F",
            "offset": 0
        }
    ],
    "extensions": ["eps"],
    "description": "Encapsulated PostScript document",
    "extended_description": "",
    "group": ""
},
{
    "format": "PDF",
    "signatures": [
        {
            "hex_signature": "25 50 44 46",
            "offset": 0
        }
    ],
    "extensions": ["pdf"],
    "description": "Portable Document Format",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "FDF",
    "signatures": [
        {
            "hex_signature": "25 50 44 46",
            "offset": 0
        }
    ],
    "extensions": ["fdf"],
    "description": "Forms Document Format",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "AI",
    "signatures": [
        {
            "hex_signature": "25 50 44 46",
            "offset": 0
        }
    ],
    "extensions": ["ai"],
    "description": "Illustrator graphics format",
    "extended_description": "",
    "group": ""
},
{
    "format": "U-Boot",
    "signatures": [
        {
            "hex_signature": "27 05 19 56",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Das U-Boot Universal Boot Loader",
    "extended_description": "",
    "group": ""
},
{
    "format": "HQX",
    "signatures": [
        {
            "hex_signature": "28 54 68 69 73 20 66 69",
            "offset": 0
        }
    ],
    "extensions": ["hqx"],
    "description": "BinHex 4 Compressed Archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "ZST",
    "signatures": [
        {
            "hex_signature": "28 B5 2F FD",
            "offset": 0
        }
    ],
    "extensions": ["zst"],
    "description": "Zstandard compressed file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "Symantec Wise Installer log",
    "signatures": [
        {
            "hex_signature": "2A 2A 2A 20 20 49 6E 73",
            "offset": 0
        }
    ],
    "extensions": ["log"],
    "description": "Symantec Wise Installer log",
    "extended_description": "",
    "group": ""
},
{
    "format": "LHA",
    "signatures": [
        {
            "hex_signature": "2D 6C 68",
            "offset": 2
        }
    ],
    "extensions": ["lha"],
    "description": "Compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "LZH",
    "signatures": [
        {
            "hex_signature": "2D 6C 68",
            "offset": 2
        }
    ],
    "extensions": ["lzh"],
    "description": "Compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "IVR",
    "signatures": [
        {
            "hex_signature": "2E 52 45 43",
            "offset": 0
        }
    ],
    "extensions": ["ivr"],
    "description": "RealPlayer video file (V11+)",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "RealAudio",
    "signatures": [
        {
            "hex_signature": "2E 52 4D 46 00 00 00 12",
            "offset": 0
        }
    ],
    "extensions": ["ra"],
    "description": "RealAudio file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "Sun Microsystems Audio",
    "signatures": [
        {
            "hex_signature": "2E 73 6E 64",
            "offset": 0
        }
    ],
    "extensions": ["au"],
    "description": "NeXT|Sun Microsystems audio file",
    "extended_description": "",
    "group": ""
},
{
    "format": "CAT",
    "signatures": [
        {
            "hex_signature": "30",
            "offset": 0
        }
    ],
    "extensions": ["cat"],
    "description": "MS security catalog file",
    "extended_description": "",
    "group": ""
},
{
    "format": "EVT",
    "signatures": [
        {
            "hex_signature": "30 00 00 00 4C 66 4C 65",
            "offset": 0
        }
    ],
    "extensions": ["evt"],
    "description": "Windows Event Viewer file",
    "extended_description": "",
    "group": ""
},
{
    "format": "WMV",
    "signatures": [
        {
            "hex_signature": "30 26 B2 75 8E 66 CF 11",
            "offset": 0
        }
    ],
    "extensions": ["wmv"],
    "description": "Windows Media Video File",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "WMA",
    "signatures": [
        {
            "hex_signature": "30 26 B2 75 8E 66 CF 11",
            "offset": 0
        }
    ],
    "extensions": ["wma"],
    "description": "Windows Media Audio File",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "ASF",
    "signatures": [
        {
            "hex_signature": "30 26 B2 75 8E 66 CF 11",
            "offset": 0
        }
    ],
    "extensions": ["asf"],
    "description": "Windows Media Audio|Video File",
    "extended_description": "",
    "group": ""
},
{
    "format": "National Transfer Format Map",
    "signatures": [
        {
            "hex_signature": "30 31 4F 52 44 4E 41 4E",
            "offset": 0
        }
    ],
    "extensions": ["ntf"],
    "description": "National Transfer Format Map",
    "extended_description": "",
    "group": ""
},
{
    "format": "cpio archive",
    "signatures": [
        {
            "hex_signature": "30 37 30 37 30",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "cpio archive",
    "extended_description": "",
    "group": ""
},
{
    "format": "DER",
    "signatures": [
        {
            "hex_signature": "30 82",
            "offset": 0
        }
    ],
    "extensions": ["der"],
    "description": "DER encoded X.509 certificate",
    "extended_description": "",
    "group": ""
},
{
    "format": "WRI",
    "signatures": [
        {
            "hex_signature": "31 BE",
            "offset": 0
        },
        {
            "hex_signature": "32 BE",
            "offset": 0
        },
        {
            "hex_signature": "BE 00 00 00 AB",
            "offset": 0
        }
    ],
    "extensions": ["wri"],
    "description": "MS Write",
    "extended_description": "",
    "group": ""
},
{
    "format": "Tcpdump Capture File",
    "signatures": [
        {
            "hex_signature": "34 CD B2 A1",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Tcpdump capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "7Z",
    "signatures": [
        {
            "hex_signature": "37 7A BC AF 27 1C",
            "offset": 0
        }
    ],
    "extensions": ["7z"],
    "description": "7-Zip compressed file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "zisofs compression format",
    "signatures": [
        {
            "hex_signature": "37 E4 53 96 C9 DB D6 07",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "zisofs compression format",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "PSD",
    "signatures": [
        {
            "hex_signature": "38 42 50 53",
            "offset": 0
        }
    ],
    "extensions": ["psd"],
    "description": "Photoshop image",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "KDBX",
    "signatures": [
        {
            "hex_signature": "67 FB 4B B5",
            "offset": 4
        }
    ],
    "extensions": ["kdbx"],
    "description": "KeePass 2 database",
    "extended_description": "",
    "group": ""
},
{
    "format": "SLE",
    "signatures": [
        {
            "hex_signature": "3A 56 45 52 53 49 4F 4E",
            "offset": 0
        }
    ],
    "extensions": ["sle"],
    "description": "Surfplan kite project file",
    "extended_description": "",
    "group": ""
},
{
    "format": "ASX",
    "signatures": [
        {
            "hex_signature": "3C 61 73 78",
            "offset": 0
        }
    ],
    "extensions": ["asx"],
    "description": "Advanced Stream Redirector",
    "extended_description": "",
    "group": ""
},
{
    "format": "DCI",
    "signatures": [
        {
            "hex_signature": "3C 21 64 6F 63 74 79 70",
            "offset": 0
        }
    ],
    "extensions": ["dci"],
    "description": "AOL HTML mail",
    "extended_description": "",
    "group": ""
},
{
    "format": "Windows Visual Stylesheet",
    "signatures": [
        {
            "hex_signature": "3C 3F 78 6D 6C 20 76 65 72 73 69 6F 6E 3D",
            "offset": 0
        }
    ],
    "extensions": ["manifest"],
    "description": "Windows Visual Stylesheet",
    "extended_description": "",
    "group": ""
},
{
    "format": "XML",
    "signatures": [
        {
            "hex_signature": "3C 3F 78 6D 6C 20 76 65 72 73 69 6F 6E 3D",
            "offset": 0
        }
    ],
    "extensions": ["xml"],
    "description": "eXtensible Markup Language file",
    "extended_description": "",
    "group": "Text"
},
{
    "format": "Microsoft Management Console Snap-in Control file",
    "signatures": [
        {
            "hex_signature": "3C 3F 78 6D 6C 20 76 65 72 73 69 6F 6E 3D 22 31 2E 30 22 3F 3E 0D 0A 3C 4D 4D 43 5F 43 6F 6E 73 6F 6C 65 46 69 6C 65 20 43 6F 6E 73 6F 6C 65 56 65 72",
            "offset": 0
        }
    ],
    "extensions": ["msc"],
    "description": "Microsoft Management Console Snap-in Control file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Adobe FrameMaker Format",
    "signatures": [
        {
            "hex_signature": "3C 4D 61 6B 65 72 46 69",
            "offset": 0
        }
    ],
    "extensions": ["mif", "fm"],
    "description": "Adobe FrameMaker format",
    "extended_description": "",
    "group": ""
},
{
    "format": "WB3",
    "signatures": [
        {
            "hex_signature": "3E 00 03 00 FE FF 09 00 06",
            "offset": 0
        }
    ],
    "extensions": ["wb3"],
    "description": "Quatro Pro for Windows 7.0",
    "extended_description": "",
    "group": ""
},
{
    "format": "ENL",
    "signatures": [
        {
            "hex_signature": "40 40 40 20 00 00 40 40 40 40",
            "offset": 0
        }
    ],
    "extensions": ["enl"],
    "description": "EndNote Library File",
    "extended_description": "",
    "group": ""
},
{
    "format": "DWG",
    "signatures": [
        {
            "hex_signature": "41 43",
            "offset": 0
        }
    ],
    "extensions": ["dwg"],
    "description": "Generic AutoCAD drawing",
    "extended_description": "",
    "group": ""
},
{
    "format": "AOL parameter and info files",
    "signatures": [
        {
            "hex_signature": "41 43 53 44",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "AOL parameter and info files",
    "extended_description": "",
    "group": ""
},
{
    "format": "Steganos virtual secure drive",
    "signatures": [
        {
            "hex_signature": "41 43 76",
            "offset": 0
        }
    ],
    "extensions": ["sle"],
    "description": "Steganos Security Suite virtual secure drive",
    "extended_description": "",
    "group": ""
},
{
    "format": "FH8",
    "signatures": [
        {
            "hex_signature": "41 47 44 33",
            "offset": 0
        }
    ],
    "extensions": ["fh8"],
    "description": "FreeHand 8 document",
    "extended_description": "",
    "group": ""
},
{
    "format": "SYW",
    "signatures": [
        {
            "hex_signature": "41 4D 59 4F",
            "offset": 0
        }
    ],
    "extensions": ["syw"],
    "description": "Harvard Graphics symbol graphic",
    "extended_description": "",
    "group": ""
},
{
    "format": "DJVU",
    "signatures": [
        {
            "hex_signature": "41 54 26 54 46",
            "offset": 0
        }
    ],
    "extensions": ["djvu", "djv"],
    "description": "DjVu document",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "AVG6 Integrity database",
    "signatures": [
        {
            "hex_signature": "41 56 47 36 5F 49 6E 74",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "AVG6 Integrity database",
    "extended_description": "",
    "group": ""
},
{
    "format": "FreeArc Compressed File",
    "signatures": [
        {
            "hex_signature": "41 72 43 01",
            "offset": 0
        }
    ],
    "extensions": ["arc"],
    "description": "FreeArc compressed file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "VCF",
    "signatures": [
        {
            "hex_signature": "42 45 47 49 4E 3A 56 43",
            "offset": 0
        }
    ],
    "extensions": ["vcf"],
    "description": "vCard",
    "extended_description": "",
    "group": ""
},
{
    "format": "BPG",
    "signatures": [
        {
            "hex_signature": "42 50 47 FB",
            "offset": 0
        }
    ],
    "extensions": ["bpg"],
    "description": "Better Portable Graphics format",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "Speedtouch router firmware",
    "signatures": [
        {
            "hex_signature": "42 4C 49 32 32 33",
            "offset": 0
        }
    ],
    "extensions": ["bin", "bli", "rbi"],
    "description": "Speedtouch router firmware",
    "extended_description": "",
    "group": ""
},
{
    "format": "BMP",
    "signatures": [
        {
            "hex_signature": "42 4D",
            "offset": 0
        }
    ],
    "extensions": ["bmp", "dib"],
    "description": "Bitmap image",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "PalmPilot Resource File",
    "signatures": [
        {
            "hex_signature": "42 4F 4F 4B 4D 4F 42 49",
            "offset": 0
        }
    ],
    "extensions": ["prc"],
    "description": "PalmPilot resource file",
    "extended_description": "",
    "group": ""
},
{
    "format": "BZIP2",
    "signatures": [
        {
            "hex_signature": "42 5A 68",
            "offset": 0
        }
    ],
    "extensions": ["bz2", "tbz2", "tb2"],
    "description": "bzip2 compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "RTD",
    "signatures": [
        {
            "hex_signature": "43 23 2B 44 A4 43 4D A5",
            "offset": 0
        }
    ],
    "extensions": ["rtd"],
    "description": "RagTime document",
    "extended_description": "",
    "group": ""
},
{
    "format": "ISO",
    "signatures": [],
    "comment": "The format recognition rules require clarification.",
    "extensions": ["iso"],
    "description": "ISO-9660 CD Disc Image",
    "extended_description": "",
    "group": ""
},
{
    "format": "Corel Binary metafile",
    "signatures": [
        {
            "hex_signature": "43 4D 58 31",
            "offset": 0
        }
    ],
    "extensions": ["clb"],
    "description": "Corel Binary metafile",
    "extended_description": "",
    "group": ""
},
{
    "format": "COM+ Catalog",
    "signatures": [
        {
            "hex_signature": "43 4F 4D 2B",
            "offset": 0
        }
    ],
    "extensions": ["clb"],
    "description": "COM+ Catalog",
    "extended_description": "",
    "group": ""
},
{
    "format": "CPT",
    "signatures": [
        {
            "hex_signature": "43 50 54 37 46 49 4C 45",
            "offset": 0
        },
        {
            "hex_signature": "43 50 54 46 49 4C 45",
            "offset": 0
        }
    ],
    "extensions": ["cpt"],
    "description": "Corel Photopaint",
    "extended_description": "",
    "group": ""
},
{
    "format": "Win9x registry hive",
    "signatures": [
        {
            "hex_signature": "43 52 45 47",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Win9x registry hive",
    "extended_description": "",
    "group": ""
},
{
    "format": "CRU",
    "signatures": [
        {
            "hex_signature": "43 52 55 53 48 20 76",
            "offset": 0
        }
    ],
    "extensions": ["cru"],
    "description": "Crush compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "SWF",
    "signatures": [
        {
            "hex_signature": "43 57 53",
            "offset": 0
        },
        {
            "hex_signature": "46 57 53",
            "offset": 0
        },
        {
            "hex_signature": "5A 57 53",
            "offset": 0
        }
    ],
    "extensions": ["swf"],
    "description": "Macromedia Shockwave Flash file format",
    "extended_description": "",
    "group": ""
},
{
    "format": "CTF",
    "signatures": [
        {
            "hex_signature": "43 61 74 61 6C 6F 67 20",
            "offset": 0
        }
    ],
    "extensions": ["ctf"],
    "description": "WhereIsIt Catalog",
    "extended_description": "",
    "group": ""
},
{
    "format": "IE cache file",
    "signatures": [
        {
            "hex_signature": "43 6C 69 65 6E 74 20 55",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "IE cache file",
    "extended_description": "",
    "group": ""
},
{
    "format": "CRX",
    "signatures": [
        {
            "hex_signature": "43 72 32 34",
            "offset": 0
        }
    ],
    "extensions": ["crx"],
    "description": "Google Chrome extension or packaged app",
    "extended_description": "",
    "group": ""
},
{
    "format": "Palm Zire photo database",
    "signatures": [
        {
            "hex_signature": "44 42 46 48",
            "offset": 0
        }
    ],
    "extensions": ["db"],
    "description": "Palm Zire photo database",
    "extended_description": "",
    "group": ""
},
{
    "format": "DMS",
    "signatures": [
        {
            "hex_signature": "44 4D 53 21",
            "offset": 0
        }
    ],
    "extensions": ["dms"],
    "description": "Amiga DiskMasher compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "ADF",
    "signatures": [
        {
            "hex_signature": "44 4F 53",
            "offset": 0
        }
    ],
    "extensions": ["adf"],
    "description": "Amiga disk file",
    "extended_description": "",
    "group": ""
},
{
    "format": "IFO",
    "signatures": [
        {
            "hex_signature": "44 56 44",
            "offset": 0
        }
    ],
    "extensions": ["ifo"],
    "description": "DVD info file",
    "extended_description": "",
    "group": ""
},
{
    "format": "DVR",
    "signatures": [
        {
            "hex_signature": "44 56 44",
            "offset": 0
        }
    ],
    "extensions": ["dvr"],
    "description": "DVR-Studio stream file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Elite Plus Commander Game file",
    "signatures": [
        {
            "hex_signature": "45 4C 49 54 45 20 43 6F",
            "offset": 0
        }
    ],
    "extensions": ["cdr"],
    "description": "Elite Plus Commander game file",
    "extended_description": "",
    "group": ""
},
{
    "format": "VCD",
    "signatures": [
        {
            "hex_signature": "45 4E 54 52 59 56 43 44",
            "offset": 0
        }
    ],
    "extensions": ["vcd"],
    "description": "VideoVCD|VCDImager file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MDI",
    "signatures": [
        {
            "hex_signature": "45 50",
            "offset": 0
        }
    ],
    "extensions": ["mdi"],
    "description": "MS Document Imaging file",
    "extended_description": "",
    "group": ""
},
{
    "format": "EasyRecovery Saved State file",
    "signatures": [
        {
            "hex_signature": "45 52 46 53 53 41 56 45",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "EasyRecovery Saved State file",
    "extended_description": "",
    "group": ""
},
{
    "format": "E01",
    "signatures": [
        {
            "hex_signature": "45 56 46",
            "offset": 0
        }
    ],
    "extensions": ["e01"],
    "description": "EnCase EWF version 1 format",
    "extended_description": "",
    "group": ""
},
{
    "format": "EX01",
    "signatures": [
        {
            "hex_signature": "45 56 46 32",
            "offset": 0
        }
    ],
    "extensions": ["ex01"],
    "description": "EnCase EWF version 2 format",
    "extended_description": "",
    "group": ""
},
{
    "format": "EVTX",
    "signatures": [
        {
            "hex_signature": "45 6C 66 46 69 6C 65 00",
            "offset": 0
        }
    ],
    "extensions": ["evtx"],
    "description": "Windows Vista event log",
    "extended_description": "",
    "group": ""
},
{
    "format": "QBB",
    "signatures": [
        {
            "hex_signature": "45 86 00 00 06 00",
            "offset": 0
        }
    ],
    "extensions": ["qbb"],
    "description": "QuickBooks backup",
    "extended_description": "",
    "group": ""
},
{
    "format": "CPE",
    "signatures": [
        {
            "hex_signature": "46 41 58 43 4F 56 45 52",
            "offset": 0
        }
    ],
    "extensions": ["cpe"],
    "description": "MS Fax Cover Sheet",
    "extended_description": "",
    "group": ""
},
{
    "format": "FLIF",
    "signatures": [
        {
            "hex_signature": "46 4C 49 46",
            "offset": 0
        }
    ],
    "extensions": ["flif"],
    "description": "Free Lossless Image Format",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "FLV",
    "signatures": [
        {
            "hex_signature": "46 4C 56",
            "offset": 0
        }
    ],
    "extensions": ["flv"],
    "description": "Flash video file",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "LZIP",
    "signatures": [
        {
            "hex_signature": "4C 5A 49 50",
            "offset": 0
        }
    ],
    "extensions": ["lz"],
    "description": "LZIP compressed file format",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "AIFF",
    "signatures": [
        {
            "hex_signature": "46 4F 52 4D 00",
            "offset": 0
        }
    ],
    "extensions": ["aiff"],
    "description": "Audio Interchange File",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "EML",
    "signatures": [
        {
            "hex_signature": "46 72 6F 6D",
            "offset": 0
        },
        {
            "hex_signature": "52 65 74 75 72 6E 2D 50",
            "offset": 0,
            "common": "A commmon file header for e-mail files"
        }
    ],
    "extensions": ["eml"],
    "description": "Generic e-mail format",
    "extended_description": "",
    "group": ""
},
{
    "format": "GIF",
    "signatures": [
        {
            "hex_signature": "47 49 46 38",
            "offset": 0
        }
    ],
    "extensions": ["gif"],
    "description": "GIF file",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "PAT",
    "signatures": [
        {
            "hex_signature": "47 50 41 54",
            "offset": 0
        }
    ],
    "extensions": ["pat"],
    "description": "GIMP pattern file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SH3",
    "signatures": [
        {
            "hex_signature": "48 48 47 42 31",
            "offset": 0
        }
    ],
    "extensions": ["sh3"],
    "description": "Harvard Graphics presentation file",
    "extended_description": "",
    "group": ""
},
{
    "format": "HIP",
    "signatures": [
        {
            "hex_signature": "48 69 50 21",
            "offset": 0
        }
    ],
    "extensions": ["hip"],
    "description": "Houdini image file",
    "extended_description": "",
    "group": ""
},
{
    "format": "TIFF",
    "signatures": [
        {
            "hex_signature": "49 20 49",
            "offset": 0
        },
        {
            "hex_signature": "49 49 2A 00",
            "offset": 0
        },
        {
            "hex_signature": "4D 4D 00 2A",
            "offset": 0
        },
        {
            "hex_signature": "4D 4D 00 2B",
            "offset": 0
        }
    ],
    "extensions": ["tif", "tiff"],
    "description": "TIFF image",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "MP3",
    "signatures": [
        {
            "hex_signature": "49 44 43",
            "offset": 0
        },
        {
            "hex_signature": "49 44 33",
            "offset": 0
        },
        {
            "hex_signature": "FF FA",
            "offset": 0
        },
        {
            "hex_signature": "FF FB",
            "offset": 0
        },
        {
            "hex_signature": "FF F2",
            "offset": 0
        },
        {
            "hex_signature": "FF F3",
            "offset": 0
        }
    ],
    "extensions": ["mp3"],
    "description": "MP3 audio file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "KOZ",
    "signatures": [
        {
            "hex_signature": "49 44 33 03 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["koz"],
    "description": "Sprint Music Store audio",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "CRW",
    "signatures": [
        {
            "hex_signature": "49 49 1A 00 00 00 48 45",
            "offset": 0
        }
    ],
    "extensions": ["crw"],
    "description": "Canon RAW file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Install Shield compressed file",
    "signatures": [
        {
            "hex_signature": "49 53 63 28",
            "offset": 0
        }
    ],
    "extensions": ["cab", "hdr"],
    "description": "Install Shield compressed file",
    "extended_description": "",
    "group": ""
},
{
    "format": "LIT",
    "signatures": [
        {
            "hex_signature": "49 54 4F 4C 49 54 4C 53",
            "offset": 0
        }
    ],
    "extensions": ["lit"],
    "description": "MS Reader eBook",
    "extended_description": "",
    "group": ""
},
{
    "format": "CHM",
    "signatures": [
        {
            "hex_signature": "49 54 53 46",
            "offset": 0
        }
    ],
    "extensions": ["chi", "chm"],
    "description": "MS Compiled HTML Help File",
    "extended_description": "",
    "group": ""
},
{
    "format": "Inno Setup Uninstall Log",
    "signatures": [
        {
            "hex_signature": "49 6E 6E 6F 20 53 65 74",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Inno Setup Uninstall Log",
    "extended_description": "",
    "group": ""
},
{
    "format": "JARCS compressed archive",
    "signatures": [
        {
            "hex_signature": "4A 41 52 43 53 00",
            "offset": 0
        }
    ],
    "extensions": ["jar"],
    "description": "JARCS compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "JG",
    "signatures": [
        {
            "hex_signature": "4A 47 03 0E",
            "offset": 0
        },
        {
            "hex_signature": "4A 47 04 0E",
            "offset": 0
        }
    ],
    "extensions": ["jg"],
    "description": "AOL ART",
    "extended_description": "",
    "group": ""
},
{
    "format": "KGB",
    "signatures": [
        {
            "hex_signature": "4B 47 42 5F 61 72 63 68",
            "offset": 0
        }
    ],
    "extensions": ["kgb"],
    "description": "KGB archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "SHD",
    "signatures": [
        {
            "hex_signature": "4B 49 00 00",
            "offset": 0
        },
        {
            "hex_signature": "66 49 00 00",
            "offset": 0
        },
        {
            "hex_signature": "67 49 00 00",
            "offset": 0
        },
        {
            "hex_signature": "68 49 00 00",
            "offset": 0
        }
    ],
    "extensions": ["shd"],
    "description": "Win9x printer spool file",
    "extended_description": "",
    "group": ""
},
{
    "format": "KWAJ",
    "signatures": [
        {
            "hex_signature": "4B 57 41 4A 88 F0 27 D1",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "KWAJ compressed file",
    "extended_description": "",
    "group": ""
},
{
    "format": "LNK",
    "signatures": [
        {
            "hex_signature": "4C 00 00 00 01 14 02 00",
            "offset": 0
        }
    ],
    "extensions": ["lnk"],
    "description": "Windows shortcut file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MS Common Object File Format",
    "signatures": [
        {
            "hex_signature": "4C 01",
            "offset": 0
        }
    ],
    "extensions": ["obj"],
    "description": "MS Common Object File Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "EWF-L01",
    "signatures": [
        {
            "hex_signature": "4C 56 46 09 0D 0A FF 00",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Logical File Evidence Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "Merriam-Webster's Pocket Dictionary",
    "signatures": [
        {
            "hex_signature": "4D 2D 57 20 50 6F 63 6B",
            "offset": 0
        }
    ],
    "extensions": ["pdb"],
    "description": "Merriam-Webster's Pocket Dictionary file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MAR",
    "signatures": [
        {
            "hex_signature": "4D 41",
            "offset": 0
        }
    ],
    "extensions": ["mar"],
    "description": "MAR archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "Windows Dump Format",
    "signatures": [
        {
            "hex_signature": "4D 44 4D 50 93 A7",
            "offset": 0
        }
    ],
    "extensions": ["hdmp", "dmp"],
    "description": "Windows dump file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Milestones Project Management Format",
    "signatures": [
        {
            "hex_signature": "4D",
            "offset": 0
        }
    ],
    "extensions": ["mls"],
    "description": "Milestones project management file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Skype localization data file",
    "signatures": [
        {
            "hex_signature": "4D 4C 53 57",
            "offset": 0
        }
    ],
    "extensions": ["mls"],
    "description": "Skype localization data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MLV",
    "signatures": [
        {
            "hex_signature": "4D 4C 56 49",
            "offset": 0
        }
    ],
    "extensions": ["mlv"],
    "description": "Magic Lantern Video format",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "MMF",
    "signatures": [
        {
            "hex_signature": "4D 4D 4D 44 00 00",
            "offset": 0
        }
    ],
    "extensions": ["mmf"],
    "description": "Yamaha Synthetic music Mobile Application Format",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "NVRAM",
    "signatures": [
        {
            "hex_signature": "4D 52 56 4E",
            "offset": 0
        }
    ],
    "extensions": ["nvram"],
    "description": "VMware BIOS state file",
    "extended_description": "",
    "group": ""
},
{
    "format": "CAB",
    "signatures": [
        {
            "hex_signature": "4D 53 43 46",
            "offset": 0
        }
    ],
    "extensions": ["cab"],
    "description": "Microsoft cabinet file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SNP",
    "signatures": [
        {
            "hex_signature": "4D 53 43 46",
            "offset": 0
        }
    ],
    "extensions": ["snp"],
    "description": "MS Access Snapshot Viewer file",
    "extended_description": "",
    "group": ""
},
{
    "format": "PPZ",
    "signatures": [
        {
            "hex_signature": "4D 53 43 46",
            "offset": 0
        }
    ],
    "extensions": ["ppz"],
    "description": "Powerpoint Packaged Presentation",
    "extended_description": "",
    "group": ""
},
{
    "format": "TLB",
    "signatures": [
        {
            "hex_signature": "4D 53 46 54 02 00 01 00",
            "offset": 0
        }
    ],
    "extensions": ["tlb"],
    "description": "OLE|SPSS|Visual C++ library file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Sony Compressed Voice File",
    "signatures": [
        {
            "hex_signature": "4D 53 5F 56 4F 49 43 45",
            "offset": 0
        }
    ],
    "extensions": ["dvf", "cdr", "msv"],
    "description": "Sony Compressed Voice File",
    "extended_description": "",
    "group": ""
},
{
    "format": "MIDI",
    "signatures": [
        {
            "hex_signature": "4D 54 68 64",
            "offset": 0
        }
    ],
    "extensions": ["midi", "mid"],
    "description": "MIDI sound file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "DSN",
    "signatures": [
        {
            "hex_signature": "4D 56",
            "offset": 0
        }
    ],
    "extensions": ["dsn"],
    "description": "CD Stomper Pro label file",
    "extended_description": "",
    "group": ""
},
{
    "format": "VBX",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["vbx"],
    "description": "VisualBASIC application",
    "extended_description": "",
    "group": ""
},
{
    "format": "Windows|DOS executable file",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["com", "dll", "drv", "exe", "pif", "qts", "qtx", "sys"],
    "description": "Windows|DOS executable file",
    "extended_description": "",
    "group": ""
},
{
    "format": "OLB",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["olb"],
    "description": "OLE object library",
    "extended_description": "",
    "group": ""
},
{
    "format": "Library Cache",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["ax"],
    "description": "Microsoft Library cache",
    "extended_description": "",
    "group": ""
},
{
    "format": "SCR",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["scr"],
    "description": "Windows screen saver",
    "extended_description": "",
    "group": ""
},
{
    "format": "OCX",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["ocx"],
    "description": "ActiveX|OLE Custom Control",
    "extended_description": "",
    "group": ""
},
{
    "format": "ACM",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["acm"],
    "description": "MS audio compression manager driver",
    "extended_description": "",
    "group": ""
},
{
    "format": "Control Panel Application",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["cpl"],
    "description": "Control panel application",
    "extended_description": "",
    "group": ""
},
{
    "format": "Windows virtual device drivers",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["386", "vxd"],
    "description": "Windows virtual device drivers",
    "extended_description": "",
    "group": ""
},
{
    "format": "FON",
    "signatures": [
        {
            "hex_signature": "4D 5A",
            "offset": 0
        }
    ],
    "extensions": ["fon"],
    "description": "Font file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Audition Graphic Filter",
    "signatures": [
        {
            "hex_signature": "4D 5A 90 00 03 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["flt"],
    "description": "Audition graphic filter",
    "extended_description": "",
    "group": ""
},
{
    "format": "AX",
    "signatures": [
        {
            "hex_signature": "4D 5A 90 00 03 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["ax"],
    "description": "DirectShow filter",
    "extended_description": "",
    "group": ""
},
{
    "format": "API",
    "signatures": [
        {
            "hex_signature": "4D 5A 90 00 03 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["api"],
    "description": "Acrobat plug-in",
    "extended_description": "",
    "group": ""
},
{
    "format": "ZAP",
    "signatures": [
        {
            "hex_signature": "4D 5A 90 00 03 00 00 00 04 00 00 00 FF FF",
            "offset": 0
        }
    ],
    "extensions": ["zap"],
    "description": "ZoneAlam data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MS C++ Debugging Symbols",
    "signatures": [
        {
            "hex_signature": "4D 69 63 72 6F 73 6F 66 74 20 43 2F 43 2B 2B 20",
            "offset": 0
        }
    ],
    "extensions": ["pdb"],
    "description": "MS C++ debugging symbols file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SLN",
    "signatures": [
        {
            "hex_signature": "4D 69 63 72 6F 73 6F 66 74 20 56 69 73 75 61 6C",
            "offset": 0
        }
    ],
    "extensions": ["sln"],
    "description": "Visual Studio .NET file",
    "extended_description": "",
    "group": ""
},
{
    "format": "WPL",
    "signatures": [
        {
            "hex_signature": "4D 69 63 72 6F 73 6F 66 74 20 57 69 6E 64 6F 77 73 20 4D 65 64 69 61 20 50 6C 61 79 65 72 20 2D 2D 20",
            "offset": 0
        }
    ],
    "extensions": ["wpl"],
    "description": "Windows Media Player playlist",
    "extended_description": "",
    "group": ""
},
{
    "format": "TomTom traffic data",
    "signatures": [
        {
            "hex_signature": "4E 41 56 54 52 41 46 46 49 43",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "TomTom traffic data",
    "extended_description": "",
    "group": ""
},
{
    "format": "MS Windows journal",
    "signatures": [
        {
            "hex_signature": "4E 42 2A 00",
            "offset": 0
        }
    ],
    "extensions": ["jtp", "jnt"],
    "description": "MS Windows journal",
    "extended_description": "",
    "group": ""
},
{
    "format": "NES",
    "signatures": [
        {
            "hex_signature": "4E 45 53 1A",
            "offset": 0
        }
    ],
    "extensions": ["nes"],
    "description": "Nintendo Entertainment System ROM file",
    "extended_description": "",
    "group": ""
},
{
    "format": "NSF",
    "signatures": [
        {
            "hex_signature": "4E 45 53 4D 1A 01",
            "offset": 0
        }
    ],
    "extensions": ["nsf"],
    "description": "NES Sound file",
    "extended_description": "",
    "group": ""
},
{
    "format": "National Imagery Transmission Format",
    "signatures": [
        {
            "hex_signature": "4E 49 54 46 30",
            "offset": 0
        }
    ],
    "extensions": ["ntf"],
    "description": "National Imagery Transmission Format file",
    "extended_description": "",
    "group": ""
},
{
    "format": "COD",
    "signatures": [
        {
            "hex_signature": "4E 61 6D 65 3A 20",
            "offset": 0
        }
    ],
    "extensions": ["cod"],
    "description": "Agent newsreader character map",
    "extended_description": "",
    "group": ""
},
{
    "format": "DBF",
    "signatures": [
        {
            "hex_signature": "4F 50 4C 44 61 74 61 62",
            "offset": 0
        }
    ],
    "extensions": ["dbf"],
    "description": "Psion Series 3 Database",
    "extended_description": "",
    "group": ""
},
{
    "format": "OTF",
    "signatures": [
        {
            "hex_signature": "4F 54 54 4F 00",
            "offset": 0
        }
    ],
    "extensions": ["otf"],
    "description": "OpenType font format",
    "extended_description": "",
    "group": ""
},
{
    "format": "OGG",
    "signatures": [
        {
            "hex_signature": "4F 67 67 53 00 02 00 00",
            "offset": 0
        }
    ],
    "extensions": ["oga", "ogg", "ogv", "ogx"],
    "description": "Ogg Vorbis Codec compressed file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "DW4",
    "signatures": [
        {
            "hex_signature": "4F 7B",
            "offset": 0
        }
    ],
    "extensions": ["dw4"],
    "description": "Visio|DisplayWrite 4 text file",
    "extended_description": "",
    "group": ""
},
{
    "format": "IDX",
    "signatures": [
        {
            "hex_signature": "50 00 00 00 20 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["idx"],
    "description": "Quicken QuickFinder Information File",
    "extended_description": "",
    "group": ""
},
{
    "format": "PGM",
    "signatures": [
        {
            "hex_signature": "50 35 0A",
            "offset": 0
        }
    ],
    "extensions": ["pgm"],
    "description": "Portable Graymap Graphic",
    "extended_description": "",
    "group": ""
},
{
    "format": "Quake archive file",
    "signatures": [
        {
            "hex_signature": "50 41 43 4B",
            "offset": 0
        }
    ],
    "extensions": ["pak"],
    "description": "Quake archive file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "DMP",
    "signatures": [
        {
            "hex_signature": "50 41 47 45 44 55",
            "offset": 0
        }
    ],
    "extensions": ["dmp"],
    "description": "Windows memory dump",
    "extended_description": "",
    "group": ""
},
{
    "format": "PAX",
    "signatures": [
        {
            "hex_signature": "50 41 58",
            "offset": 0
        }
    ],
    "extensions": ["pax"],
    "description": "PAX password protected bitmap",
    "extended_description": "",
    "group": ""
},
{
    "format": "PestPatrol data|scan strings",
    "signatures": [
        {
            "hex_signature": "50 45 53 54",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "PestPatrol data|scan strings",
    "extended_description": "",
    "group": ""
},
{
    "format": "PGD",
    "signatures": [
        {
            "hex_signature": "50 47 50 64 4D 41 49 4E",
            "offset": 0
        }
    ],
    "extensions": ["pgd"],
    "description": "PGP disk image",
    "extended_description": "",
    "group": ""
},
{
    "format": "ChromaGraph Graphics Card Bitmap",
    "signatures": [
        {
            "hex_signature": "50 49 43 54 00 08",
            "offset": 0
        }
    ],
    "extensions": ["img"],
    "description": "ChromaGraph Graphics Card Bitmap",
    "extended_description": "",
    "group": ""
},
{
    "format": "ZIP",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        },
        {
            "hex_signature": "50 4B 05 06",
            "offset": 0
        },
        {
            "hex_signature": "50 4B 07 08",
            "offset": 0
        }
    ],
    "extensions": ["zip"],
    "description": "PKZIP",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "JAR",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["jar"],
    "description": "Java archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "KMZ",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["kmz"],
    "description": "Google Earth saved working session",
    "extended_description": "",
    "group": ""
},
{
    "format": "KWD",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["kwd"],
    "description": "KWord document",
    "extended_description": "",
    "group": ""
},
{
    "format": "ODT",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["odt"],
    "description": "OpenDocument text document",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "ODS",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["ods"],
    "description": "OpenDocument table",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "ODP",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["odp"],
    "description": "OpenDocument presentation",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "OTT",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["ott"],
    "description": "OpenDocument text template",
    "extended_description": "",
    "group": ""
},
{
    "format": "OXPS",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["oxps"],
    "description": "Microsoft Open XML paper specification",
    "extended_description": "",
    "group": ""
},
{
    "format": "SXC",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["sxc"],
    "description": "StarOffice spreadsheet",
    "extended_description": "",
    "group": ""
},
{
    "format": "WMZ",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["wmz"],
    "description": "Windows Media compressed skin file",
    "extended_description": "",
    "group": ""
},
{
    "format": "XPI",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["xpi"],
    "description": "Mozilla Browser Archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "XPS",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["xps"],
    "description": "XML paper specification",
    "extended_description": "",
    "group": ""
},
{
    "format": "XPT",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["xpt"],
    "description": "eXact Packager Models",
    "extended_description": "",
    "group": ""
},
{
    "format": "CUIX",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["cuix"],
    "description": "Customization files",
    "extended_description": "",
    "group": ""
},
{
    "format": "DOCX",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04 14 00 06 00",
            "offset": 0
        }
    ],
    "extensions": ["docx"],
    "description": "MS Office Word Document",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "XLSX",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04 14 00 06 00",
            "offset": 0
        }
    ],
    "extensions": ["xlsx"],
    "description": "MS Office Excel Table",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "PPTX",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04 14 00 06 00",
            "offset": 0
        }
    ],
    "extensions": ["pptx"],
    "description": "MS Office PowerPoint Presentation",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "PKLITE",
    "signatures": [
        {
            "hex_signature": "50 4B 4C 49 54 45",
            "offset": 0
        }
    ],
    "extensions": ["zip"],
    "description": "PKLITE archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "PKSFX",
    "signatures": [
        {
            "hex_signature": "50 4B 53 70 58",
            "offset": 0
        }
    ],
    "extensions": ["zip"],
    "description": "PKSFX self-extracting archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "GRP",
    "signatures": [
        {
            "hex_signature": "50 4D 43 43",
            "offset": 0
        }
    ],
    "extensions": ["grp"],
    "description": "Windows Program Manager group file",
    "extended_description": "",
    "group": ""
},
{
    "format": "QEL",
    "signatures": [
        {
            "hex_signature": "51 45 4C 20",
            "offset": 0
        }
    ],
    "extensions": ["qel"],
    "description": "QDL Quicken data",
    "extended_description": "",
    "group": ""
},
{
    "format": "Qcow Disk Image",
    "signatures": [
        {
            "hex_signature": "51 46 49",
            "offset": 0
        }
    ],
    "extensions": ["qemu", "img"],
    "description": "Qcow Disk Image",
    "extended_description": "",
    "group": ""
},
{
    "format": "Quicken data file",
    "signatures": [
        {
            "hex_signature": "51 57 20 56 65 72 2E 20",
            "offset": 0
        }
    ],
    "extensions": ["abd", "qsd"],
    "description": "Quicken data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Shareaza (P2P) thumbnail",
    "signatures": [
        {
            "hex_signature": "52 41 5A 41 54 44 42 31",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Shareaza (P2P) thumbnail",
    "extended_description": "",
    "group": ""
},
{
    "format": "RDATA",
    "signatures": [
        {
            "hex_signature": "52 44 58 32 0A",
            "offset": 0
        }
    ],
    "extensions": ["rdata"],
    "description": "R saved work space",
    "extended_description": "",
    "group": ""
},
{
    "format": "WinNT Registry",
    "signatures": [
        {
            "hex_signature": "52 45 47 45 44 49 54",
            "offset": 0
        }
    ],
    "extensions": ["reg", "sud"],
    "description": "WinNT Registry|Registry Undo files",
    "extended_description": "",
    "group": ""
},
{
    "format": "Antenna data file",
    "signatures": [
        {
            "hex_signature": "52 45 56 4E 55 4D 3A 2C",
            "offset": 0
        }
    ],
    "extensions": ["ad", "adf"],
    "description": "Antenna data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "4XM",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["4xm"],
    "description": "4X Movie video",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "Video CD MPEG movie",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Video CD MPEG movie",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "CMX",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["cmx"],
    "description": "Corel Presentation Exchange metadata",
    "extended_description": "",
    "group": ""
},
{
    "format": "CDR",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["cdr"],
    "description": "CorelDraw document",
    "extended_description": "",
    "group": ""
},
{
    "format": "DS4",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["ds4"],
    "description": "Micrografx Designer graphic",
    "extended_description": "",
    "group": ""
},
{
    "format": "AVI",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["avi"],
    "description": "Audio Video Interleave video format",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "ANI",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["ani"],
    "description": "Windows animated cursor",
    "extended_description": "",
    "group": ""
},
{
    "format": "CDA",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["cda"],
    "description": "Resource Interchange File Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "QCP",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["qcp"],
    "description": "Resource Interchange File Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "RMI",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["rmi"],
    "description": "Resource Interchange File Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "WAV",
    "signatures": [
        {
            "hex_signature": "52 49 46 46",
            "offset": 0
        }
    ],
    "extensions": ["wav"],
    "description": "Waveform Audio File Format",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "WinNT Netmon Capture",
    "signatures": [
        {
            "hex_signature": "52 54 53 53",
            "offset": 0
        }
    ],
    "extensions": ["cap"],
    "description": "WinNT Netmon capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "RAR",
    "signatures": [
        {
            "hex_signature": "52 61 72 21 1A 07",
            "offset": 0
        }
    ],
    "extensions": ["rar"],
    "description": "WinRAR compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "AST",
    "signatures": [
        {
            "hex_signature": "53 43 48 6C",
            "offset": 0
        }
    ],
    "extensions": ["ast"],
    "description": "Underground Audio",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "Img Software Bitmap",
    "signatures": [
        {
            "hex_signature": "53 43 4D 49",
            "offset": 0
        }
    ],
    "extensions": ["img"],
    "description": "Img Software Bitmap",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "SHW",
    "signatures": [
        {
            "hex_signature": "53 48 4F 57",
            "offset": 0
        }
    ],
    "extensions": ["shw"],
    "description": "Harvard Graphics presentation",
    "extended_description": "",
    "group": ""
},
{
    "format": "Sietronics CPI XRD",
    "signatures": [
        {
            "hex_signature": "53 49 45 54 52 4F 4E 49",
            "offset": 0
        }
    ],
    "extensions": ["cpi"],
    "description": "Sietronics CPI XRD document",
    "extended_description": "",
    "group": ""
},
{
    "format": "SIT",
    "signatures": [
        {
            "hex_signature": "53 49 54 21 00",
            "offset": 0
        },
        {
            "hex_signature": "53 74 75 66 66 49 74 20",
            "offset": 0
        }
    ],
    "extensions": ["sit"],
    "description": "StuffIt compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "SDR",
    "signatures": [
        {
            "hex_signature": "53 4D 41 52 54 44 52 57",
            "offset": 0
        }
    ],
    "extensions": ["sdr"],
    "description": "SmartDraw Drawing file",
    "extended_description": "",
    "group": ""
},
{
    "format": "CNV",
    "signatures": [
        {
            "hex_signature": "53 51 4C 4F 43 4F 4E 56",
            "offset": 0
        }
    ],
    "extensions": ["cnv"],
    "description": "DB2 conversion file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SQLite Database",
    "signatures": [
        {
            "hex_signature": "53 51 4C 69 74 65 20 66 6F 72 6D 61 74 20 33 00",
            "offset": 0
        }
    ],
    "extensions": ["db", "sqlitedb", "sqlite"],
    "description": "SQLite database file format",
    "extended_description": "",
    "group": ""
},
{
    "format": "QBASIC SZDD File Header",
    "signatures": [
        {
            "hex_signature": "53 5A 20 88 F0 27 33 D1",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "QBASIC SZDD file header format",
    "extended_description": "",
    "group": ""
},
{
    "format": "SZDD File Format",
    "signatures": [
        {
            "hex_signature": "53 5A 44 44 88 F0 27 33",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "SZDD file format",
    "extended_description": "",
    "group": ""
},
{
    "format": "SuperCalc Worksheet",
    "signatures": [
        {
            "hex_signature": "53 75 70 65 72 43 61 6C",
            "offset": 0
        }
    ],
    "extensions": ["cal"],
    "description": "SuperCalc worksheet",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "TDEF",
    "signatures": [
        {
            "hex_signature": "54 44 45 46",
            "offset": 0
        }
    ],
    "extensions": ["tdef"],
    "description": "Telegram Desktop Encrypted File",
    "extended_description": "",
    "group": ""
},
{
    "format": "INFO",
    "signatures": [
        {
            "hex_signature": "54 68 69 73 20 69 73 20",
            "offset": 0
        }
    ],
    "extensions": ["info"],
    "description": "GNU Info Reader file",
    "extended_description": "",
    "group": ""
},
{
    "format": "UCE",
    "signatures": [
        {
            "hex_signature": "55 43 45 58",
            "offset": 0
        }
    ],
    "extensions": ["uce"],
    "description": "Unicode extensions",
    "extended_description": "",
    "group": ""
},
{
    "format": "UFA",
    "signatures": [
        {
            "hex_signature": "55 46 41 C6 D2 C1",
            "offset": 0
        }
    ],
    "extensions": ["ufa"],
    "description": "UFA compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "UFO Capture map file",
    "signatures": [
        {
            "hex_signature": "55 46 4F 4F 72 62 69 74",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "UFO Capture map file",
    "extended_description": "",
    "group": ""
},
{
    "format": "PCH",
    "signatures": [
        {
            "hex_signature": "56 43 50 43 48 30",
            "offset": 0
        }
    ],
    "extensions": ["pch"],
    "description": "Visual C PreCompiled header",
    "extended_description": "",
    "group": ""
},
{
    "format": "CTL",
    "signatures": [
        {
            "hex_signature": "56 45 52 53 49 4F 4E 20",
            "offset": 0
        }
    ],
    "extensions": ["ctl"],
    "description": "Visual Basic User-defined Control file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MIF",
    "signatures": [
        {
            "hex_signature": "56 65 72 73 69 6F 6E 20",
            "offset": 0
        }
    ],
    "extensions": ["mif"],
    "description": "MapInfo Interchange Format file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Walkman MP3",
    "signatures": [
        {
            "hex_signature": "57 4D 4D 50",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Walkman MP3 container file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "WS2",
    "signatures": [
        {
            "hex_signature": "57 53 32 30 30 30",
            "offset": 0
        }
    ],
    "extensions": ["ws2"],
    "description": "WordStar for Windows file",
    "extended_description": "",
    "group": ""
},
{
    "format": "LWP",
    "signatures": [
        {
            "hex_signature": "57 6F 72 64 50 72 6F",
            "offset": 0
        }
    ],
    "extensions": ["lwp"],
    "description": "Lotus WordPro file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Exchange e-mail",
    "signatures": [
        {
            "hex_signature": "58 2D",
            "offset": 0
        }
    ],
    "extensions": ["eml"],
    "description": "Exchange e-mail",
    "extended_description": "",
    "group": ""
},
{
    "format": "CAP",
    "signatures": [
        {
            "hex_signature": "58 43 50 00",
            "offset": 0
        }
    ],
    "extensions": ["cap"],
    "description": "Packet sniffer files",
    "extended_description": "",
    "group": ""
},
{
    "format": "XPCOM",
    "signatures": [
        {
            "hex_signature": "58 50 43 4F 4D 0A 54 79",
            "offset": 0
        }
    ],
    "extensions": ["xpt"],
    "description": "XPCOM libraries",
    "extended_description": "",
    "group": ""
},
{
    "format": "BDR",
    "signatures": [
        {
            "hex_signature": "58 54",
            "offset": 0
        }
    ],
    "extensions": ["bdr"],
    "description": "MS Publisher border",
    "extended_description": "",
    "group": ""
},
{
    "format": "ZOO",
    "signatures": [
        {
            "hex_signature": "5A 4F 4F 20",
            "offset": 0
        }
    ],
    "extensions": ["zoo"],
    "description": "ZOO compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "ECF",
    "signatures": [
        {
            "hex_signature": "5B 47 65 6E 65 72 61 6C",
            "offset": 0
        }
    ],
    "extensions": ["ecf"],
    "description": "MS Exchange configuration file",
    "extended_description": "",
    "group": ""
},
{
    "format": "VCW",
    "signatures": [
        {
            "hex_signature": "5B 4D 53 56 43",
            "offset": 0
        }
    ],
    "extensions": ["vcw"],
    "description": "Visual C++ Workbench Info File",
    "extended_description": "",
    "group": ""
},
{
    "format": "DUN",
    "signatures": [
        {
            "hex_signature": "5B 50 68 6F 6E 65 5D",
            "offset": 0
        }
    ],
    "extensions": ["dun"],
    "description": "Dial-up networking file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SAM",
    "signatures": [
        {
            "hex_signature": "5B 56 45 52 5D",
            "offset": 0
        },
        {
            "hex_signature": "5B 76 65 72 5D",
            "offset": 0
        }
    ],
    "extensions": ["sam"],
    "description": "Lotus AMI Pro document",
    "extended_description": "",
    "group": ""
},
{
    "format": "Identifier",
    "signatures": [
        {
            "hex_signature": "5B 5A 6F 6E 65",
            "offset": 0
        }
    ],
    "extensions": ["Identifier"],
    "description": "Microsoft Zone Identifier for URL Security Zones",
    "extended_description": "",
    "group": ""
},
{
    "format": "CPX",
    "signatures": [
        {
            "hex_signature": "5B 57 69 6E 64 6F 77 73",
            "offset": 0
        }
    ],
    "extensions": ["cpx"],
    "description": "Microsoft Code Page Translation file",
    "extended_description": "",
    "group": ""
},
{
    "format": "CFG",
    "signatures": [
        {
            "hex_signature": "5B 66 6C 74 73 69 6D 2E",
            "offset": 0
        }
    ],
    "extensions": ["cfg"],
    "description": "Flight Simulator Aircraft Configuration",
    "extended_description": "",
    "group": ""
},
{
    "format": "Jar archive",
    "signatures": [
        {
            "hex_signature": "5F 27 A8 89",
            "offset": 0
        }
    ],
    "extensions": ["jar"],
    "description": "Jar archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "CAS",
    "signatures": [
        {
            "hex_signature": "5F 43 41 53 45 5F",
            "offset": 0
        }
    ],
    "extensions": ["cas", "cbk"],
    "description": "EnCase case file",
    "extended_description": "",
    "group": ""
},
{
    "format": "ARJ",
    "signatures": [
        {
            "hex_signature": "60 EA",
            "offset": 0
        }
    ],
    "extensions": ["arj"],
    "description": "ARJ Compressed archive file",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "UUencoded file",
    "signatures": [
        {
            "hex_signature": "62 65 67 69 6E",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "UUencoded file",
    "extended_description": "",
    "group": ""
},
{
    "format": "macOS file Alias",
    "signatures": [
        {
            "hex_signature": "62 6F 6F 6B 00",
            "offset": 0
        }
    ],
    "extensions": ["alias"],
    "description": "macOS file Alias",
    "extended_description": "",
    "group": ""
},
{
    "format": "plist",
    "signatures": [
        {
            "hex_signature": "62 70 6C 69 73 74",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Binary property list (plist)",
    "extended_description": "",
    "group": ""
},
{
    "format": "VHD",
    "signatures": [
        {
            "hex_signature": "63 6F 6E 65 63 74 69 78",
            "offset": 0
        }
    ],
    "extensions": ["vhd"],
    "description": "Virtual PC HD image",
    "extended_description": "",
    "group": ""
},
{
    "format": "CSH",
    "signatures": [
        {
            "hex_signature": "63 75 73 68 00 00 00 02",
            "offset": 0
        }
    ],
    "extensions": ["csh"],
    "description": "Photoshop Custom Shape",
    "extended_description": "",
    "group": ""
},
{
    "format": "P10",
    "signatures": [
        {
            "hex_signature": "64 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["p10"],
    "description": "Intel PROset|Wireless Profile",
    "extended_description": "",
    "group": ""
},
{
    "format": "DEX",
    "signatures": [
        {
            "hex_signature": "64 65 78 0A",
            "offset": 0
        }
    ],
    "extensions": ["dex"],
    "description": "Dalvik (Android) executable file format",
    "extended_description": "",
    "group": ""
},
{
    "format": "AU",
    "signatures": [
        {
            "hex_signature": "64 6E 73 2E",
            "offset": 0
        }
    ],
    "extensions": ["au"],
    "description": "Audacity audio file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "DSW",
    "signatures": [
        {
            "hex_signature": "64 73 77 66 69 6C 65",
            "offset": 0
        }
    ],
    "extensions": ["dsw"],
    "description": "MS Visual Studio workspace file",
    "extended_description": "",
    "group": ""
},
{
    "format": "FLAC",
    "signatures": [
        {
            "hex_signature": "66 4C 61 43 00 00 00 22",
            "offset": 0
        }
    ],
    "extensions": ["flac"],
    "description": "Free Lossless Audio Codec file",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "3GP",
    "signatures": [
        {
            "hex_signature": "66 74 79 70 33 67 70",
            "offset": 4
        }
    ],
    "extensions": ["3gg", "3gp", "3g2"],
    "description": "3GP",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "MOV",
    "signatures": [
        {
            "hex_signature": "66 72 65 65",
            "offset": 4
        },
        {
            "hex_signature": "66 74 79 70 71 74 20 20",
            "offset": 4
        },
        {
            "hex_signature": "6D 64 61 74",
            "offset": 4
        },
        {
            "hex_signature": "6D 6F 6F 76",
            "offset": 4
        },
        {
            "hex_signature": "70 6E 6F 74",
            "offset": 4
        },
        {
            "hex_signature": "73 6B 69 70",
            "offset": 4
        },
        {
            "hex_signature": "77 69 64 65",
            "offset": 4
        }
    ],
    "extensions": ["mov"],
    "description": "QuickTime movie",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "M4A",
    "signatures": [
        {
            "hex_signature": "66 74 79 70",
            "offset": 4
        }
    ],
    "extensions": ["m4a"],
    "description": "Apple Lossless Audio Codec format",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "MP4",
    "signatures": [
        {
            "hex_signature": "66 74 79 70",
            "offset": 4
        }
    ],
    "extensions": ["mp4"],
    "description": "MPEG-4 video format",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "M4V",
    "signatures": [
        {
            "hex_signature": "66 74 79 70 6D 70 34 32",
            "offset": 4
        },
        {
            "hex_signature": "66 74 79 70 4D 34 56 20",
            "offset": 4
        }
    ],
    "extensions": ["m4v"],
    "description": "MPEG-4 video | QuickTime",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "XCF",
    "signatures": [
        {
            "hex_signature": "67 69 6d 70 20 78 63 66 20",
            "offset": 0
        }
    ],
    "extensions": ["xcf"],
    "description": "GIMP eXperimental Computing Facility image format",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "DBB",
    "signatures": [
        {
            "hex_signature": "6C 33 33 6C",
            "offset": 0
        }
    ],
    "extensions": ["dbb"],
    "description": "Skype user data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SMS",
    "signatures": [
        {
            "hex_signature": "6F 3C",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "SMS text (SIM)",
    "extended_description": "",
    "group": ""
},
{
    "format": "WinNT Registry File",
    "signatures": [
        {
            "hex_signature": "72 65 67 66",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "WinNT registry file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Sonic Foundry Acid Music",
    "signatures": [
        {
            "hex_signature": "72 69 66 66",
            "offset": 0
        }
    ],
    "extensions": ["ac", "acd"],
    "description": "Sonic Foundry Acid Music Format",
    "extended_description": "",
    "group": ""
},
{
    "format": "RAM",
    "signatures": [
        {
            "hex_signature": "72 74 73 70 3A 2F 2F",
            "offset": 0
        }
    ],
    "extensions": ["ram"],
    "description": "RealMedia metafile",
    "extended_description": "",
    "group": ""
},
{
    "format": "Allegro Generic Packfile",
    "signatures": [
        {
            "hex_signature": "73 6C 68 21",
            "offset": 0,
            "comment": "compressed"
        },
        {
            "hex_signature": "73 6C 68 2E",
            "offset": 0,
            "comment": "uncompressed"
        }
    ],
    "extensions": ["dat"],
    "description": "Allegro Generic Packfile (compressed)",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "CAL",
    "signatures": [
        {
            "hex_signature": "73 72 63 64 6F 63 69 64",
            "offset": 0
        }
    ],
    "extensions": ["cal"],
    "description": "CALS raster bitmap",
    "extended_description": "",
    "group": ""
},
{
    "format": "PowerBASIC Debugging Symbols",
    "signatures": [
        {
            "hex_signature": "73 7A 65 7A",
            "offset": 0
        }
    ],
    "extensions": ["pdb"],
    "description": "PowerBASIC Debugging Symbols",
    "extended_description": "",
    "group": ""
},
{
    "format": "PRC",
    "signatures": [
        {
            "hex_signature": "74 42 4D 50 4B 6E 57 72",
            "offset": 0
        }
    ],
    "extensions": ["prc"],
    "description": "PathWay Map file",
    "extended_description": "",
    "group": ""
},
{
    "format": "TTF",
    "signatures": [
        {
            "hex_signature": "00 01 00 00 00",
            "offset": 0
        },
        {
            "hex_signature": "74 72 75 65 00",
            "offset": 0
        }
    ],
    "extensions": ["ttf"],
    "description": "TrueType font format",
    "extended_description": "",
    "group": ""
},
{
    "format": "TAR",
    "signatures": [
        {
            "hex_signature": "75 73 74 61 72",
            "offset": 257
        }
    ],
    "extensions": ["tar"],
    "description": "Tape Archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "FLT",
    "signatures": [
        {
            "hex_signature": "76 32 30 30 33 2E 31 30",
            "offset": 0
        }
    ],
    "extensions": ["flt"],
    "description": "Qimage filter",
    "extended_description": "",
    "group": ""
},
{
    "format": "DMG",
    "signatures": [
        {
            "hex_signature": "78 01 73 0D 62 62 60",
            "offset": 0
        }
    ],
    "extensions": ["dmg"],
    "description": "MacOS X disk image",
    "extended_description": "",
    "group": ""
},
{
    "format": "XAR",
    "signatures": [
        {
            "hex_signature": "78 61 72 21",
            "offset": 0
        }
    ],
    "extensions": ["xar"],
    "description": "eXtensible ARchive format",
    "extended_description": "",
    "group": ""
},
{
    "format": "ZoomBrowser Image Index",
    "signatures": [
        {
            "hex_signature": "7A 62 65 78",
            "offset": 0
        }
    ],
    "extensions": ["info"],
    "description": "ZoomBrowser Image Index",
    "extended_description": "",
    "group": ""
},
{
    "format": "Windows application log",
    "signatures": [
        {
            "hex_signature": "7B 0D 0A 6F 20",
            "offset": 0
        }
    ],
    "extensions": ["lgc", "lgd"],
    "description": "Windows application log",
    "extended_description": "",
    "group": ""
},
{
    "format": "PWI",
    "signatures": [
        {
            "hex_signature": "7B 5C 70 77 69",
            "offset": 0
        }
    ],
    "extensions": ["pwi"],
    "description": "MS WinMobile personal note",
    "extended_description": "",
    "group": ""
},
{
    "format": "RTF",
    "signatures": [
        {
            "hex_signature": "7B 5C 72 74 66",
            "offset": 0
        }
    ],
    "extensions": ["rtf"],
    "description": "RTF text format",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "PSP",
    "signatures": [
        {
            "hex_signature": "7E 42 4B 00",
            "offset": 0
        }
    ],
    "extensions": ["psp"],
    "description": "Corel Paint Shop Pro image",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "ELF executable",
    "signatures": [
        {
            "hex_signature": "7F 45 4C 46",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "ELF executable",
    "extended_description": "",
    "group": ""
},
{
    "format": "OBJ",
    "signatures": [
        {
            "hex_signature": "80",
            "offset": 0
        }
    ],
    "extensions": ["obj"],
    "description": "Relocatable object code",
    "extended_description": "",
    "group": ""
},
{
    "format": "ADX",
    "signatures": [
        {
            "hex_signature": "80 00 00 20 03 12 04",
            "offset": 0
        }
    ],
    "extensions": ["adx"],
    "description": "Dreamcast audio",
    "extended_description": "",
    "group": "Audio"
},
{
    "format": "WAB",
    "signatures": [
        {
            "hex_signature": "81 32 84 C1 85 05 D0 11",
            "offset": 0,
            "comment": "Outlook Express address book (Win95)"
        },
        {
            "hex_signature": "9C CB CB 8D 13 75 D2 11",
            "offset": 0
        }
    ],
    "extensions": ["wab"],
    "description": "Outlook Express address file",
    "extended_description": "",
    "group": ""
},
{
    "format": "WPF",
    "signatures": [
        {
            "hex_signature": "81 CD AB",
            "offset": 0
        }
    ],
    "extensions": ["wpf"],
    "description": "WordPerfect text",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "PNG",
    "signatures": [
        {
            "hex_signature": "89 50 4E 47 0D 0A 1A 0A",
            "offset": 0
        }
    ],
    "extensions": ["png"],
    "description": "Portable Network Graphics format",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "AW",
    "signatures": [
        {
            "hex_signature": "8A 01 09 00 00 00 E1 08",
            "offset": 0
        }
    ],
    "extensions": ["aw"],
    "description": "MS Answer Wizard",
    "extended_description": "",
    "group": ""
},
{
    "format": "HAP",
    "signatures": [
        {
            "hex_signature": "91 33 48 46",
            "offset": 0
        }
    ],
    "extensions": ["hap"],
    "description": "Hamarsoft compressed archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "SKR",
    "signatures": [
        {
            "hex_signature": "95 00",
            "offset": 0
        },
        {
            "hex_signature": "95 01",
            "offset": 0
        }
    ],
    "extensions": ["skr"],
    "description": "PGP secret",
    "extended_description": "",
    "group": ""
},
{
    "format": "GPG",
    "signatures": [
        {
            "hex_signature": "99",
            "offset": 0
        }
    ],
    "extensions": ["gpg"],
    "description": "GPG public keyring",
    "extended_description": "",
    "group": ""
},
{
    "format": "PKR",
    "signatures": [
        {
            "hex_signature": "99 01",
            "offset": 0
        }
    ],
    "extensions": ["pkr"],
    "description": "PGP public keyring",
    "extended_description": "",
    "group": ""
},
{
    "format": "tcpdump",
    "signatures": [
        {
            "hex_signature": "A1 B2 C3 D4",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "tcpdump (libpcap) capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Extended tcpdump",
    "signatures": [
        {
            "hex_signature": "A1 B2 CD 34",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Extended tcpdump (libpcap) capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Access Data FTK evidence",
    "signatures": [
        {
            "hex_signature": "A9 0D 00 00 00 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["dat"],
    "description": "Access Data FTK evidence",
    "extended_description": "",
    "group": ""
},
{
    "format": "QDF",
    "signatures": [
        {
            "hex_signature": "AC 9E BD 8F 00 00",
            "offset": 0
        }
    ],
    "extensions": ["qdf"],
    "description": "QDF Quicken data",
    "extended_description": "",
    "group": ""
},
{
    "format": "Java serialization data",
    "signatures": [
        {
            "hex_signature": "AC ED",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Java serialization data",
    "extended_description": "",
    "group": ""
},
{
    "format": "BGBlitz Position Database",
    "signatures": [
        {
            "hex_signature": "AC ED 00 05 73 72 00 12",
            "offset": 0
        }
    ],
    "extensions": ["pdb"],
    "description": "BGBlitz Position Database File",
    "extended_description": "",
    "group": ""
},
{
    "format": "PWL for Win95",
    "signatures": [
        {
            "hex_signature": "B0 4D 46 43",
            "offset": 0
        }
    ],
    "extensions": ["pwl"],
    "description": "Win95 password file",
    "extended_description": "",
    "group": ""
},
{
    "format": "DCX",
    "signatures": [
        {
            "hex_signature": "B1 68 DE 3A",
            "offset": 0
        }
    ],
    "extensions": ["dcx"],
    "description": "PCX bitmap",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "TIB",
    "signatures": [
        {
            "hex_signature": "B4 6E 68 44",
            "offset": 0
        }
    ],
    "extensions": ["tib"],
    "description": "Acronis True Image",
    "extended_description": "",
    "group": ""
},
{
    "format": "Windows Calendar Format",
    "signatures": [
        {
            "hex_signature": "B5 A2 B0 B3 B3 B0 A5 B5",
            "offset": 0
        }
    ],
    "extensions": ["cal"],
    "description": "Windows calendar",
    "extended_description": "",
    "group": ""
},
{
    "format": "ACS",
    "signatures": [
        {
            "hex_signature": "C3 AB CD AB",
            "offset": 0
        }
    ],
    "extensions": ["acs"],
    "description": "MS Agent Character file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Abobe EPS",
    "signatures": [
        {
            "hex_signature": "C5 D0 D3 C6",
            "offset": 0
        }
    ],
    "extensions": ["eps"],
    "description": "Adobe encapsulated PostScript",
    "extended_description": "",
    "group": ""
},
{
    "format": "LBK",
    "signatures": [
        {
            "hex_signature": "C8 00 79 00",
            "offset": 0
        }
    ],
    "extensions": ["lbk"],
    "description": "Jeppesen FliteLog file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Java bytecode",
    "signatures": [
        {
            "hex_signature": "CA FE BA BE",
            "offset": 0
        }
    ],
    "extensions": ["class"],
    "description": "Java bytecode",
    "extended_description": "",
    "group": ""
},
{
    "format": "NAV quarantined virus file",
    "signatures": [
        {
            "hex_signature": "CD 20 AA AA 02 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "Norton Antivirus quarantined virus file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Perfect Office document",
    "signatures": [
        {
            "hex_signature": "CF 11 E0 A1 B1 1A E1 00",
            "offset": 0
        }
    ],
    "extensions": ["doc"],
    "description": "Perfect Office document",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "DBX",
    "signatures": [
        {
            "hex_signature": "CF AD 12 FE",
            "offset": 0
        }
    ],
    "extensions": ["dbx"],
    "description": "Outlook Express e-mail folder",
    "extended_description": "",
    "group": ""
},
{
    "format": "DOC",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["doc"],
    "description": "MS Office text document",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "DOT",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["dot"],
    "description": "MS Office document",
    "extended_description": "",
    "group": ""
},
{
    "format": "PPT",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["ppt"],
    "description": "MS Office presentation",
    "extended_description": "",
    "group": ""
},
{
    "format": "PPS",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["pps"],
    "description": "MS Office document",
    "extended_description": "",
    "group": ""
},
{
    "format": "PUB",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["pub"],
    "description": "MS Publisher file",
    "extended_description": "",
    "group": ""
},
{
    "format": "WIZ",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["wiz"],
    "description": "Microsoft Office document",
    "extended_description": "",
    "group": ""
},
{
    "format": "MSI",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["msi"],
    "description": "Microsoft Installer package",
    "extended_description": "",
    "group": ""
},
{
    "format": "Microsoft Common Console Document",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["msc"],
    "description": "Microsoft Common Console Document",
    "extended_description": "",
    "group": ""
},
{
    "format": "XLA",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["xla"],
    "description": "Microsoft Office document",
    "extended_description": "",
    "group": ""
},
{
    "format": "VSD",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["vsd"],
    "description": "Visio file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MS Works Database File",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["db"],
    "description": "Microsoft Works database file",
    "extended_description": "",
    "group": ""
},
{
    "format": "OPT",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["opt"],
    "description": "Developer Studio File Options file",
    "extended_description": "",
    "group": ""
},
{
    "format": "SOU",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["sou"],
    "description": "Visual Studio Solution User Options file",
    "extended_description": "",
    "group": ""
},
{
    "format": "APR",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["apr"],
    "description": "Lotus|IBM Approach 97 file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MTW",
    "signatures": [
        {
            "hex_signature": "D0 CF 11 E0 A1 B1 1A E1",
            "offset": 0
        }
    ],
    "extensions": ["mtw"],
    "description": "Minitab data file",
    "extended_description": "",
    "group": ""
},
{
    "format": "FTR",
    "signatures": [
        {
            "hex_signature": "D2 0A 00 00",
            "offset": 0
        }
    ],
    "extensions": ["ftr"],
    "description": "WinPharoah filter file",
    "extended_description": "",
    "group": ""
},
{
    "format": "AOL history|typed URL files",
    "signatures": [
        {
            "hex_signature": "D4 2A",
            "offset": 0
        }
    ],
    "extensions": ["arl", "aut"],
    "description": "AOL history|typed URL files",
    "extended_description": "",
    "group": ""
},
{
    "format": "WinDump (winpcap) capture file",
    "signatures": [
        {
            "hex_signature": "D4 C3 B2 A1",
            "offset": 0
        }
    ],
    "extensions": ["*"],
    "description": "WinDump (winpcap) capture file",
    "extended_description": "",
    "group": ""
},
{
    "format": "WMF",
    "signatures": [
        {
            "hex_signature": "D7 CD C6 9A",
            "offset": 0
        }
    ],
    "extensions": ["wmf"],
    "description": "Windows graphics metafile",
    "extended_description": "",
    "group": ""
},
{
    "format": "Word 2.0 file",
    "signatures": [
        {
            "hex_signature": "DB A5 2D 00",
            "offset": 0
        }
    ],
    "extensions": ["doc"],
    "description": "Word 2.0 file",
    "extended_description": "",
    "group": ""
},
{
    "format": "CPL",
    "signatures": [
        {
            "hex_signature": "DC DC",
            "offset": 0
        }
    ],
    "extensions": ["cpl"],
    "description": "Corel color palette",
    "extended_description": "",
    "group": ""
},
{
    "format": "EFX",
    "signatures": [
        {
            "hex_signature": "DC FE",
            "offset": 0
        }
    ],
    "extensions": ["efx"],
    "description": "eFax file",
    "extended_description": "",
    "group": ""
},
{
    "format": "Amiga icon",
    "signatures": [
        {
            "hex_signature": "E3 10 00 01 00 00 00 00",
            "offset": 0
        }
    ],
    "extensions": ["info"],
    "description": "Amiga icon",
    "extended_description": "",
    "group": ""
},
{
    "format": "PWL for Win98",
    "signatures": [
        {
            "hex_signature": "E3 82 85 96",
            "offset": 0
        }
    ],
    "extensions": ["pwl"],
    "description": "Win98 password file",
    "extended_description": "",
    "group": ""
},
{
    "format": "ONE",
    "signatures": [
        {
            "hex_signature": "E4 52 5C 7B 8C D8 A7 4D",
            "offset": 0
        }
    ],
    "extensions": ["one"],
    "description": "MS OneNote note",
    "extended_description": "",
    "group": ""
},
{
    "format": "COM",
    "signatures": [
        {
            "hex_signature": "E8",
            "offset": 0
        },
        {
            "hex_signature": "E9",
            "offset": 0
        },
        {
            "hex_signature": "EB",
            "offset": 0
        }
    ],
    "extensions": ["com"],
    "description": "Windows executable",
    "extended_description": "",
    "group": ""
},
{
    "format": "SYS",
    "signatures": [
        {
            "hex_signature": "E8",
            "offset": 0
        },
        {
            "hex_signature": "E9",
            "offset": 0
        },
        {
            "hex_signature": "EB",
            "offset": 0
        },
        {
            "hex_signature": "FF",
            "offset": 0
        }
    ],
    "extensions": ["sys"],
    "description": "Windows executable",
    "extended_description": "",
    "group": ""
},
{
    "format": "GEM Raster file",
    "signatures": [
        {
            "hex_signature": "EB 3C 90 2A",
            "offset": 0
        }
    ],
    "extensions": ["img"],
    "description": "GEM Raster file",
    "extended_description": "",
    "group": ""
},
{
    "format": "RPM",
    "signatures": [
        {
            "hex_signature": "ED AB EE DB",
            "offset": 0
        }
    ],
    "extensions": ["rpm"],
    "description": "RedHat Package format",
    "extended_description": "",
    "group": ""
},
{
    "format": "XZ",
    "signatures": [
        {
            "hex_signature": "FD 37 1A 58 5A 00 00",
            "offset": 0
        }
    ],
    "extensions": ["xz"],
    "description": "XZ archive",
    "extended_description": "",
    "group": "Archives"
},
{
    "format": "Symantex Ghost image file",
    "signatures": [
        {
            "hex_signature": "FE EF",
            "offset": 0
        }
    ],
    "extensions": ["ghs", "gho"],
    "description": "Symantex Ghost image file",
    "extended_description": "",
    "group": ""
},
{
    "format": "WKS",
    "signatures": [
        {
            "hex_signature": "FF 00 02 00 04 04 05 54",
            "offset": 0
        }
    ],
    "extensions": ["wks"],
    "description": "Works for Windows spreadsheet",
    "extended_description": "",
    "group": ""
},
{
    "format": "CPI",
    "signatures": [
        {
            "hex_signature": "FF 46 4F 4E 54",
            "offset": 0
        }
    ],
    "extensions": ["cpi"],
    "description": "Windows international code page",
    "extended_description": "",
    "group": ""
},
{
    "format": "WordPerfect format",
    "signatures": [
        {
            "hex_signature": "FF 57 50 43",
            "offset": 0
        }
    ],
    "extensions": ["wpp", "wpg", "wpd", "wp6", "wp5", "wp"],
    "description": "WordPerfect text and graphics",
    "extended_description": "",
    "group": ""
},
{
    "format": "JPEG",
    "signatures": [
        {
            "hex_signature": "FF D8 FF",
            "offset": 0
        }
    ],
    "extensions": ["jpe", "jfif", "jpeg", "jpg"],
    "description": "JPEG image",
    "extended_description": "",
    "group": "Pictures"
},
{
    "format": "REG",
    "signatures": [
        {
            "hex_signature": "FF FE",
            "offset": 0
        }
    ],
    "extensions": ["reg", "*"],
    "description": "Windows Registry file",
    "extended_description": "",
    "group": ""
},
{
    "format": "MOF",
    "signatures": [
        {
            "hex_signature": "FF FE 23 00 6C 00 69 00",
            "offset": 0
        }
    ],
    "extensions": ["mof"],
    "description": "MSinfo file",
    "extended_description": "",
    "group": ""
},
{
    "format": "DOS system driver",
    "signatures": [
        {
            "hex_signature": "FF FF FF FF",
            "offset": 0
        }
    ],
    "extensions": ["sys"],
    "description": "DOS system driver",
    "extended_description": "",
    "group": ""
},
{
    "format": "TS",
    "signatures": [
        {
            "hex_signature": "47 40",
            "offset": 0
        }
    ],
    "extensions": ["ts"],
    "description": "TS mediacontainer",
    "extended_description": "",
    "group": "Video"
},
{
    "format": "FB2",
    "signatures": [
        {
            "hex_signature": "3C 3F 78 6D 6C 20 76 65 72 73 69 6F 6E 3D",
            "offset": 0
        }
    ],
    "extensions": ["fb2"],
    "description": "FictionBook document",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "EPUB",
    "signatures": [
        {
            "hex_signature": "50 4B 03 04",
            "offset": 0
        }
    ],
    "extensions": ["epub"],
    "description": "Electronic Publication format",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "HTML",
    "signatures": [],
    "extensions": ["html"],
    "description": "HyperText Markup Language file",
    "extended_description": "",
    "group": "Text"
},
{
    "format": "MOBI",
    "signatures": [
        {
            "hex_signature": "00 00 00 00 00 00 00 00 00 00 00 00 42 4F 4F 4B 4D 4F 42 49",
            "offset": 48
        }
    ],
    "extensions": ["mobi"],
    "description": "Mobipocket e-book format",
    "extended_description": "",
    "group": "Documents"
},
{
    "format": "Torrent",
    "signatures": [
        {
            "hex_signature": "64 38 3A 61 6E 6E 6F 75 6E 63 65",
            "offset": 0
        }
    ],
    "extensions": ["torrent"],
    "description": "Torrent file",
    "extended_description": "",
    "group": ""
}
]
`;
